//line php5/php5.y:2
package php5

import __yyfmt__ "fmt"

//line php5/php5.y:2
import (
	"strconv"
	"strings"

	"github.com/z7zmey/php-parser/meta"
	"github.com/z7zmey/php-parser/node"
	"github.com/z7zmey/php-parser/node/expr"
	"github.com/z7zmey/php-parser/node/expr/assign"
	"github.com/z7zmey/php-parser/node/expr/binary"
	"github.com/z7zmey/php-parser/node/expr/cast"
	"github.com/z7zmey/php-parser/node/name"
	"github.com/z7zmey/php-parser/node/scalar"
	"github.com/z7zmey/php-parser/node/stmt"
	"github.com/z7zmey/php-parser/scanner"
)

//line php5/php5.y:22
type yySymType struct {
	yys                     int
	node                    node.Node
	token                   *scanner.Token
	list                    []node.Node
	simpleIndirectReference simpleIndirectReference

	ClassExtends     *stmt.ClassExtends
	ClassImplements  *stmt.ClassImplements
	InterfaceExtends *stmt.InterfaceExtends
	ClosureUse       *expr.ClosureUse
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EXIT = 57348
const T_IF = 57349
const T_LNUMBER = 57350
const T_DNUMBER = 57351
const T_STRING = 57352
const T_STRING_VARNAME = 57353
const T_VARIABLE = 57354
const T_NUM_STRING = 57355
const T_INLINE_HTML = 57356
const T_CHARACTER = 57357
const T_BAD_CHARACTER = 57358
const T_ENCAPSED_AND_WHITESPACE = 57359
const T_CONSTANT_ENCAPSED_STRING = 57360
const T_ECHO = 57361
const T_DO = 57362
const T_WHILE = 57363
const T_ENDWHILE = 57364
const T_FOR = 57365
const T_ENDFOR = 57366
const T_FOREACH = 57367
const T_ENDFOREACH = 57368
const T_DECLARE = 57369
const T_ENDDECLARE = 57370
const T_AS = 57371
const T_SWITCH = 57372
const T_ENDSWITCH = 57373
const T_CASE = 57374
const T_DEFAULT = 57375
const T_BREAK = 57376
const T_CONTINUE = 57377
const T_GOTO = 57378
const T_FUNCTION = 57379
const T_CONST = 57380
const T_RETURN = 57381
const T_TRY = 57382
const T_CATCH = 57383
const T_FINALLY = 57384
const T_THROW = 57385
const T_USE = 57386
const T_INSTEADOF = 57387
const T_GLOBAL = 57388
const T_VAR = 57389
const T_UNSET = 57390
const T_ISSET = 57391
const T_EMPTY = 57392
const T_HALT_COMPILER = 57393
const T_CLASS = 57394
const T_TRAIT = 57395
const T_INTERFACE = 57396
const T_EXTENDS = 57397
const T_IMPLEMENTS = 57398
const T_OBJECT_OPERATOR = 57399
const T_DOUBLE_ARROW = 57400
const T_LIST = 57401
const T_ARRAY = 57402
const T_CALLABLE = 57403
const T_CLASS_C = 57404
const T_TRAIT_C = 57405
const T_METHOD_C = 57406
const T_FUNC_C = 57407
const T_LINE = 57408
const T_FILE = 57409
const T_COMMENT = 57410
const T_DOC_COMMENT = 57411
const T_OPEN_TAG = 57412
const T_OPEN_TAG_WITH_ECHO = 57413
const T_CLOSE_TAG = 57414
const T_WHITESPACE = 57415
const T_START_HEREDOC = 57416
const T_END_HEREDOC = 57417
const T_DOLLAR_OPEN_CURLY_BRACES = 57418
const T_CURLY_OPEN = 57419
const T_PAAMAYIM_NEKUDOTAYIM = 57420
const T_NAMESPACE = 57421
const T_NS_C = 57422
const T_DIR = 57423
const T_NS_SEPARATOR = 57424
const T_ELLIPSIS = 57425
const T_EVAL = 57426
const T_REQUIRE = 57427
const T_REQUIRE_ONCE = 57428
const T_LOGICAL_OR = 57429
const T_LOGICAL_XOR = 57430
const T_LOGICAL_AND = 57431
const T_INSTANCEOF = 57432
const T_NEW = 57433
const T_CLONE = 57434
const T_ELSEIF = 57435
const T_ELSE = 57436
const T_ENDIF = 57437
const T_PRINT = 57438
const T_YIELD = 57439
const T_STATIC = 57440
const T_ABSTRACT = 57441
const T_FINAL = 57442
const T_PRIVATE = 57443
const T_PROTECTED = 57444
const T_PUBLIC = 57445
const T_INC = 57446
const T_DEC = 57447
const T_YIELD_FROM = 57448
const T_INT_CAST = 57449
const T_DOUBLE_CAST = 57450
const T_STRING_CAST = 57451
const T_ARRAY_CAST = 57452
const T_OBJECT_CAST = 57453
const T_BOOL_CAST = 57454
const T_UNSET_CAST = 57455
const T_COALESCE = 57456
const T_SPACESHIP = 57457
const T_NOELSE = 57458
const T_PLUS_EQUAL = 57459
const T_MINUS_EQUAL = 57460
const T_MUL_EQUAL = 57461
const T_POW_EQUAL = 57462
const T_DIV_EQUAL = 57463
const T_CONCAT_EQUAL = 57464
const T_MOD_EQUAL = 57465
const T_AND_EQUAL = 57466
const T_OR_EQUAL = 57467
const T_XOR_EQUAL = 57468
const T_SL_EQUAL = 57469
const T_SR_EQUAL = 57470
const T_BOOLEAN_OR = 57471
const T_BOOLEAN_AND = 57472
const T_POW = 57473
const T_SL = 57474
const T_SR = 57475
const T_IS_IDENTICAL = 57476
const T_IS_NOT_IDENTICAL = 57477
const T_IS_EQUAL = 57478
const T_IS_NOT_EQUAL = 57479
const T_IS_SMALLER_OR_EQUAL = 57480
const T_IS_GREATER_OR_EQUAL = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_DOUBLE_ARROW",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_INSTANCEOF",
	"T_NEW",
	"T_CLONE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_PRINT",
	"T_YIELD",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_INC",
	"T_DEC",
	"T_YIELD_FROM",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"T_COALESCE",
	"T_SPACESHIP",
	"T_NOELSE",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_POW_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"T_POW",
	"T_SL",
	"T_SR",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_SMALLER_OR_EQUAL",
	"T_IS_GREATER_OR_EQUAL",
	"'\"'",
	"'`'",
	"'{'",
	"'}'",
	"';'",
	"':'",
	"'('",
	"')'",
	"'['",
	"']'",
	"'?'",
	"'&'",
	"'-'",
	"'+'",
	"'!'",
	"'~'",
	"'@'",
	"'$'",
	"','",
	"'|'",
	"'='",
	"'^'",
	"'*'",
	"'/'",
	"'%'",
	"'<'",
	"'>'",
	"'.'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line php5/php5.y:6801
type simpleIndirectReference struct {
	all  []*expr.Variable
	last *expr.Variable
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 2,
	1, 1,
	-2, 0,
	-1, 51,
	104, 435,
	105, 435,
	-2, 433,
	-1, 102,
	78, 332,
	-2, 411,
	-1, 114,
	78, 451,
	146, 447,
	-2, 457,
	-1, 154,
	104, 435,
	105, 435,
	-2, 433,
	-1, 204,
	144, 306,
	147, 306,
	-2, 430,
	-1, 205,
	104, 435,
	105, 435,
	144, 307,
	147, 307,
	-2, 433,
	-1, 271,
	78, 451,
	-2, 457,
	-1, 298,
	78, 334,
	-2, 413,
	-1, 302,
	146, 448,
	-2, 458,
	-1, 311,
	78, 333,
	-2, 412,
	-1, 378,
	134, 0,
	135, 0,
	136, 0,
	137, 0,
	-2, 274,
	-1, 379,
	134, 0,
	135, 0,
	136, 0,
	137, 0,
	-2, 275,
	-1, 380,
	134, 0,
	135, 0,
	136, 0,
	137, 0,
	-2, 276,
	-1, 381,
	134, 0,
	135, 0,
	136, 0,
	137, 0,
	-2, 277,
	-1, 382,
	138, 0,
	139, 0,
	165, 0,
	166, 0,
	-2, 278,
	-1, 383,
	138, 0,
	139, 0,
	165, 0,
	166, 0,
	-2, 279,
	-1, 384,
	138, 0,
	139, 0,
	165, 0,
	166, 0,
	-2, 280,
	-1, 385,
	138, 0,
	139, 0,
	165, 0,
	166, 0,
	-2, 281,
	-1, 392,
	104, 435,
	105, 435,
	-2, 433,
	-1, 400,
	147, 142,
	-2, 147,
	-1, 462,
	104, 435,
	105, 435,
	147, 515,
	158, 515,
	-2, 433,
	-1, 463,
	147, 516,
	158, 516,
	-2, 430,
	-1, 464,
	104, 435,
	105, 435,
	-2, 433,
	-1, 486,
	147, 156,
	158, 156,
	-2, 430,
	-1, 487,
	104, 435,
	105, 435,
	147, 157,
	158, 157,
	-2, 433,
	-1, 493,
	146, 472,
	-2, 517,
	-1, 499,
	146, 472,
	-2, 518,
	-1, 521,
	78, 332,
	-2, 369,
	-1, 539,
	93, 135,
	94, 135,
	95, 135,
	-2, 0,
	-1, 551,
	147, 142,
	-2, 147,
	-1, 564,
	147, 142,
	-2, 147,
	-1, 581,
	144, 308,
	147, 308,
	-2, 430,
	-1, 582,
	104, 435,
	105, 435,
	144, 309,
	147, 309,
	-2, 433,
	-1, 682,
	78, 334,
	-2, 371,
	-1, 780,
	134, 0,
	135, 0,
	136, 0,
	137, 0,
	-2, 397,
	-1, 781,
	134, 0,
	135, 0,
	136, 0,
	137, 0,
	-2, 398,
	-1, 782,
	134, 0,
	135, 0,
	136, 0,
	137, 0,
	-2, 399,
	-1, 783,
	134, 0,
	135, 0,
	136, 0,
	137, 0,
	-2, 400,
	-1, 784,
	138, 0,
	139, 0,
	165, 0,
	166, 0,
	-2, 401,
	-1, 785,
	138, 0,
	139, 0,
	165, 0,
	166, 0,
	-2, 402,
	-1, 786,
	138, 0,
	139, 0,
	165, 0,
	166, 0,
	-2, 403,
	-1, 787,
	138, 0,
	139, 0,
	165, 0,
	166, 0,
	-2, 404,
	-1, 790,
	78, 333,
	-2, 370,
	-1, 840,
	37, 201,
	-2, 198,
	-1, 880,
	31, 128,
	32, 128,
	33, 128,
	143, 128,
	-2, 0,
	-1, 915,
	95, 140,
	-2, 0,
	-1, 917,
	31, 127,
	32, 127,
	33, 127,
	143, 127,
	-2, 0,
	-1, 944,
	93, 136,
	94, 136,
	95, 136,
	-2, 0,
	-1, 972,
	29, 189,
	-2, 4,
	-1, 981,
	147, 142,
	-2, 147,
	-1, 998,
	144, 193,
	-2, 195,
}

const yyPrivate = 57344

const yyLast = 8982

var yyAct = [...]int{

	102, 571, 844, 565, 1007, 966, 715, 61, 420, 827,
	123, 131, 919, 200, 340, 594, 567, 607, 452, 816,
	461, 808, 474, 735, 592, 684, 138, 140, 421, 142,
	145, 390, 39, 98, 444, 579, 264, 517, 118, 319,
	158, 315, 331, 330, 447, 7, 6, 544, 485, 130,
	2, 43, 26, 979, 960, 938, 228, 228, 162, 477,
	935, 942, 289, 941, 44, 670, 658, 664, 665, 672,
	673, 674, 675, 678, 679, 932, 822, 940, 658, 1003,
	251, 267, 738, 654, 258, 710, 662, 656, 655, 562,
	153, 658, 664, 665, 661, 654, 663, 657, 659, 660,
	676, 677, 666, 516, 298, 358, 325, 204, 654, 657,
	659, 660, 656, 655, 270, 736, 241, 137, 933, 794,
	954, 898, 657, 659, 660, 192, 311, 666, 729, 316,
	320, 955, 934, 323, 922, 899, 329, 854, 633, 5,
	543, 510, 126, 619, 121, 586, 121, 192, 586, 634,
	121, 658, 664, 665, 620, 511, 339, 141, 678, 679,
	585, 228, 159, 560, 114, 475, 179, 39, 654, 977,
	556, 586, 656, 655, 561, 310, 357, 115, 930, 162,
	432, 557, 657, 659, 660, 676, 677, 666, 179, 182,
	183, 718, 241, 267, 506, 228, 201, 178, 180, 181,
	908, 493, 296, 121, 359, 450, 595, 121, 507, 177,
	176, 229, 352, 355, 230, 907, 905, 104, 360, 178,
	180, 181, 862, 228, 175, 856, 270, 356, 117, 386,
	233, 425, 350, 658, 664, 665, 672, 673, 674, 675,
	678, 679, 312, 494, 792, 271, 351, 126, 746, 121,
	654, 1019, 640, 662, 656, 655, 313, 133, 272, 658,
	393, 661, 228, 663, 657, 659, 660, 676, 677, 666,
	456, 134, 301, 231, 231, 333, 654, 336, 300, 750,
	302, 612, 632, 717, 232, 232, 499, 611, 121, 120,
	631, 120, 126, 228, 121, 303, 423, 741, 265, 604,
	625, 624, 446, 241, 605, 1002, 595, 160, 978, 273,
	126, 597, 121, 596, 131, 396, 229, 931, 509, 230,
	473, 305, 513, 749, 294, 293, 521, 287, 440, 281,
	254, 253, 951, 451, 916, 233, 886, 451, 492, 463,
	39, 436, 437, 498, 491, 883, 541, 871, 120, 497,
	484, 472, 120, 7, 6, 658, 826, 271, 815, 521,
	502, 229, 486, 505, 230, 295, 728, 437, 436, 436,
	272, 437, 654, 584, 694, 635, 656, 655, 231, 229,
	233, 626, 230, 430, 399, 428, 657, 659, 660, 232,
	307, 666, 548, 546, 120, 914, 552, 593, 233, 1014,
	981, 572, 893, 572, 577, 572, 580, 139, 228, 297,
	265, 825, 231, 819, 126, 126, 121, 121, 451, 439,
	683, 273, 877, 232, 587, 588, 39, 564, 448, 297,
	810, 809, 192, 120, 551, 434, 400, 458, 537, 120,
	231, 449, 353, 344, 288, 278, 345, 5, 275, 274,
	250, 232, 539, 295, 222, 540, 616, 120, 196, 195,
	194, 144, 467, 122, 448, 492, 498, 453, 471, 448,
	581, 491, 497, 179, 479, 480, 1011, 449, 1010, 231,
	135, 495, 449, 229, 268, 1000, 230, 269, 990, 228,
	232, 985, 617, 615, 177, 176, 446, 984, 618, 704,
	705, 490, 233, 233, 178, 180, 181, 924, 316, 175,
	231, 913, 320, 309, 504, 308, 881, 521, 126, 812,
	400, 232, 704, 705, 682, 806, 521, 805, 799, 713,
	700, 547, 39, 521, 521, 521, 521, 521, 545, 542,
	501, 398, 348, 531, 91, 7, 6, 156, 636, 646,
	982, 649, 572, 906, 653, 711, 606, 701, 228, 228,
	228, 120, 120, 521, 1020, 572, 719, 976, 727, 39,
	39, 918, 892, 891, 889, 732, 531, 572, 580, 733,
	578, 306, 730, 197, 435, 267, 192, 228, 228, 714,
	125, 448, 448, 706, 179, 708, 740, 224, 225, 875,
	724, 831, 803, 804, 449, 449, 295, 518, 743, 731,
	811, 681, 734, 455, 613, 739, 742, 126, 270, 448,
	126, 737, 448, 424, 448, 231, 126, 179, 490, 228,
	745, 228, 449, 703, 446, 449, 232, 449, 259, 5,
	651, 755, 257, 438, 696, 697, 125, 610, 988, 688,
	124, 459, 648, 128, 129, 521, 521, 521, 521, 521,
	521, 521, 521, 521, 521, 521, 521, 521, 521, 521,
	521, 521, 521, 521, 521, 521, 521, 521, 521, 521,
	521, 521, 790, 759, 521, 463, 573, 126, 757, 574,
	758, 515, 321, 295, 638, 639, 454, 721, 132, 486,
	642, 643, 260, 261, 800, 295, 231, 842, 793, 791,
	427, 521, 972, 843, 426, 304, 841, 232, 228, 848,
	849, 850, 847, 846, 845, 299, 126, 687, 126, 469,
	572, 817, 832, 865, 531, 282, 286, 572, 851, 820,
	512, 508, 259, 531, 295, 259, 829, 438, 814, 271,
	531, 531, 531, 531, 531, 322, 852, 833, 743, 317,
	448, 595, 272, 857, 859, 457, 468, 848, 849, 850,
	847, 846, 845, 449, 744, 231, 231, 231, 569, 570,
	531, 573, 263, 576, 574, 285, 232, 232, 232, 521,
	192, 504, 751, 295, 295, 521, 521, 573, 132, 404,
	574, 402, 265, 208, 231, 231, 260, 261, 295, 260,
	261, 876, 895, 273, 207, 232, 232, 986, 228, 828,
	228, 878, 824, 521, 884, 882, 572, 890, 885, 879,
	1008, 179, 182, 183, 801, 726, 45, 987, 189, 191,
	821, 559, 259, 901, 572, 904, 231, 438, 231, 338,
	1018, 39, 177, 176, 62, 54, 259, 232, 992, 232,
	888, 284, 178, 180, 181, 188, 190, 175, 228, 900,
	519, 521, 531, 531, 531, 531, 531, 531, 531, 531,
	531, 531, 531, 531, 531, 531, 531, 531, 531, 531,
	531, 531, 531, 531, 531, 531, 531, 531, 531, 923,
	909, 531, 958, 519, 446, 470, 260, 261, 796, 163,
	39, 226, 234, 521, 937, 813, 704, 705, 239, 285,
	260, 261, 855, 707, 704, 705, 880, 910, 531, 259,
	860, 861, 956, 521, 45, 231, 521, 874, 926, 521,
	453, 572, 963, 572, 971, 39, 232, 39, 610, 599,
	797, 601, 600, 897, 259, 39, 894, 39, 39, 283,
	259, 521, 550, 1004, 999, 256, 572, 971, 961, 936,
	957, 983, 902, 959, 39, 126, 962, 761, 39, 39,
	521, 760, 572, 723, 652, 994, 650, 572, 996, 647,
	998, 602, 469, 260, 261, 915, 514, 917, 980, 481,
	395, 324, 203, 39, 572, 1012, 531, 925, 202, 927,
	928, 1013, 531, 531, 199, 572, 1016, 993, 260, 261,
	920, 39, 136, 920, 260, 261, 1, 830, 748, 754,
	448, 864, 944, 445, 609, 231, 948, 231, 589, 949,
	531, 842, 590, 449, 591, 39, 232, 843, 232, 685,
	841, 39, 255, 946, 840, 995, 965, 964, 903, 483,
	896, 519, 839, 836, 566, 973, 1006, 1005, 725, 394,
	519, 389, 164, 341, 698, 538, 929, 519, 519, 519,
	519, 519, 290, 460, 161, 231, 157, 318, 531, 314,
	127, 403, 575, 401, 991, 335, 232, 945, 1009, 343,
	939, 848, 849, 850, 847, 846, 845, 519, 528, 608,
	997, 970, 969, 968, 967, 838, 169, 171, 170, 192,
	837, 835, 40, 568, 15, 14, 823, 720, 802, 1015,
	531, 695, 11, 686, 249, 75, 76, 116, 1021, 266,
	689, 690, 691, 692, 693, 64, 834, 89, 598, 90,
	531, 520, 101, 531, 74, 12, 531, 326, 167, 168,
	179, 182, 183, 184, 185, 186, 187, 189, 191, 100,
	99, 79, 119, 810, 809, 526, 3, 41, 531, 193,
	173, 177, 176, 0, 0, 0, 0, 0, 172, 0,
	174, 178, 180, 181, 188, 190, 175, 531, 0, 519,
	519, 519, 519, 519, 519, 519, 519, 519, 519, 519,
	519, 519, 519, 519, 519, 519, 519, 519, 519, 519,
	519, 519, 519, 519, 519, 519, 0, 0, 519, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	669, 667, 668, 0, 0, 519, 0, 0, 0, 0,
	0, 0, 762, 763, 764, 765, 766, 767, 768, 769,
	770, 771, 772, 773, 774, 775, 776, 777, 778, 779,
	780, 781, 782, 783, 784, 785, 786, 787, 789, 0,
	0, 686, 671, 670, 658, 664, 665, 672, 673, 674,
	675, 678, 679, 0, 0, 669, 667, 668, 870, 0,
	0, 654, 0, 680, 662, 656, 655, 0, 0, 0,
	0, 0, 661, 0, 663, 657, 659, 660, 676, 677,
	666, 0, 0, 519, 0, 0, 0, 0, 0, 519,
	519, 0, 0, 0, 0, 0, 0, 671, 670, 658,
	664, 665, 672, 673, 674, 675, 678, 679, 0, 0,
	0, 0, 31, 0, 0, 798, 654, 519, 680, 662,
	656, 655, 0, 0, 0, 0, 0, 661, 0, 663,
	657, 659, 660, 676, 677, 666, 147, 151, 155, 0,
	0, 0, 165, 0, 0, 0, 869, 0, 0, 51,
	198, 0, 872, 873, 0, 206, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 519, 223, 0, 0, 0,
	235, 236, 237, 238, 192, 154, 240, 0, 242, 243,
	244, 245, 246, 247, 248, 0, 252, 0, 0, 0,
	0, 262, 205, 0, 0, 0, 276, 277, 0, 279,
	280, 0, 0, 0, 0, 227, 227, 519, 0, 0,
	291, 0, 0, 167, 168, 179, 182, 183, 184, 185,
	186, 187, 189, 191, 0, 0, 0, 519, 911, 0,
	519, 0, 0, 519, 193, 173, 177, 176, 0, 0,
	0, 0, 0, 172, 0, 174, 178, 180, 181, 188,
	190, 175, 240, 0, 0, 519, 0, 342, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	943, 0, 0, 0, 519, 0, 0, 0, 0, 0,
	361, 362, 363, 364, 365, 366, 367, 368, 369, 370,
	371, 372, 373, 374, 375, 376, 377, 378, 379, 380,
	381, 382, 383, 384, 385, 0, 387, 0, 155, 0,
	354, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 406, 408, 409, 410, 411, 412, 413, 414,
	415, 416, 417, 418, 419, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 391, 392, 671, 670, 658, 664,
	665, 672, 673, 674, 675, 678, 679, 0, 0, 0,
	0, 0, 0, 240, 0, 654, 433, 433, 662, 656,
	655, 0, 422, 441, 0, 0, 661, 0, 663, 657,
	659, 660, 676, 677, 666, 0, 0, 155, 465, 0,
	0, 466, 0, 0, 433, 0, 0, 0, 0, 0,
	433, 291, 0, 0, 0, 0, 433, 433, 0, 0,
	155, 443, 0, 433, 496, 0, 0, 0, 0, 500,
	0, 0, 0, 0, 462, 464, 0, 0, 0, 83,
	84, 72, 0, 105, 106, 126, 88, 121, 0, 0,
	0, 0, 478, 95, 0, 0, 0, 487, 0, 0,
	210, 211, 212, 213, 214, 215, 216, 217, 218, 219,
	220, 221, 45, 0, 0, 0, 549, 0, 0, 0,
	0, 0, 0, 553, 81, 82, 0, 0, 0, 0,
	621, 0, 0, 0, 52, 96, 0, 94, 110, 111,
	112, 107, 108, 209, 0, 0, 0, 0, 0, 93,
	0, 555, 0, 0, 143, 113, 109, 103, 489, 85,
	86, 87, 0, 0, 0, 0, 80, 53, 155, 912,
	0, 78, 42, 149, 0, 0, 0, 0, 0, 55,
	56, 0, 65, 66, 67, 68, 69, 70, 71, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 669, 667,
	668, 0, 0, 0, 0, 582, 0, 583, 0, 0,
	0, 0, 0, 0, 614, 92, 77, 0, 0, 0,
	0, 63, 482, 97, 0, 0, 488, 58, 57, 59,
	60, 73, 120, 0, 0, 0, 0, 0, 627, 629,
	671, 670, 658, 664, 665, 672, 673, 674, 675, 678,
	679, 668, 637, 0, 0, 0, 0, 0, 0, 654,
	0, 680, 662, 656, 655, 0, 0, 0, 0, 0,
	661, 0, 663, 657, 659, 660, 676, 677, 666, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 478, 0,
	0, 671, 670, 658, 664, 665, 672, 673, 674, 675,
	678, 679, 0, 0, 192, 342, 702, 0, 0, 0,
	654, 0, 680, 662, 656, 655, 0, 712, 0, 0,
	0, 661, 0, 663, 657, 659, 660, 676, 677, 666,
	210, 211, 212, 213, 214, 215, 216, 217, 218, 219,
	220, 221, 0, 0, 0, 179, 182, 183, 184, 185,
	186, 187, 189, 191, 558, 0, 433, 391, 716, 716,
	0, 669, 667, 668, 0, 173, 177, 176, 747, 0,
	0, 0, 0, 209, 433, 752, 178, 180, 181, 188,
	190, 175, 0, 155, 0, 0, 422, 422, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 155, 0, 0,
	0, 0, 0, 671, 670, 658, 664, 665, 672, 673,
	674, 675, 678, 679, 169, 171, 170, 192, 0, 0,
	462, 0, 654, 868, 680, 662, 656, 655, 478, 0,
	478, 0, 0, 661, 487, 663, 657, 659, 660, 676,
	677, 666, 210, 211, 212, 213, 214, 215, 216, 217,
	218, 219, 220, 221, 0, 0, 167, 168, 179, 182,
	183, 184, 185, 186, 187, 189, 191, 807, 0, 0,
	863, 0, 0, 0, 0, 0, 0, 193, 173, 177,
	176, 0, 0, 0, 0, 209, 172, 0, 174, 178,
	180, 181, 188, 190, 175, 0, 0, 0, 0, 0,
	0, 853, 0, 0, 433, 0, 0, 0, 0, 0,
	0, 0, 433, 433, 0, 0, 0, 818, 0, 866,
	0, 0, 0, 0, 0, 0, 0, 210, 211, 212,
	213, 214, 215, 216, 217, 218, 219, 220, 221, 0,
	0, 0, 0, 4, 0, 83, 84, 72, 18, 105,
	106, 13, 88, 121, 349, 30, 0, 0, 0, 95,
	29, 20, 19, 0, 21, 0, 33, 0, 34, 342,
	209, 22, 0, 0, 0, 23, 24, 38, 45, 16,
	25, 36, 0, 0, 37, 10, 0, 27, 0, 32,
	81, 82, 8, 46, 48, 50, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 716, 0, 422,
	9, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 28,
	47, 49, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 478, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 17, 645, 35, 0, 63, 0, 97,
	0, 0, 0, 58, 57, 59, 60, 73, 120, 4,
	0, 83, 84, 72, 18, 105, 106, 13, 88, 121,
	0, 30, 0, 0, 0, 95, 29, 20, 19, 0,
	21, 0, 33, 0, 34, 0, 0, 22, 0, 0,
	0, 23, 24, 38, 45, 16, 25, 36, 0, 0,
	37, 10, 0, 27, 0, 32, 81, 82, 8, 46,
	48, 50, 0, 0, 0, 0, 52, 96, 0, 94,
	110, 111, 112, 107, 108, 0, 0, 0, 0, 0,
	0, 93, 0, 0, 0, 0, 9, 113, 109, 103,
	0, 85, 86, 87, 0, 0, 0, 0, 80, 53,
	0, 0, 0, 78, 42, 28, 47, 49, 0, 0,
	0, 55, 56, 0, 65, 66, 67, 68, 69, 70,
	71, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 92, 77, 17,
	503, 35, 0, 63, 0, 97, 0, 0, 0, 58,
	57, 59, 60, 73, 120, 4, 0, 83, 84, 72,
	18, 105, 106, 13, 88, 121, 0, 30, 0, 0,
	0, 95, 29, 20, 19, 0, 21, 0, 33, 0,
	34, 0, 0, 22, 0, 0, 0, 23, 24, 38,
	45, 16, 25, 36, 0, 0, 37, 10, 0, 27,
	0, 32, 81, 82, 8, 46, 48, 50, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 9, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	42, 28, 47, 49, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 17, 0, 35, 0, 63,
	0, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 328, 0, 83, 84, 72, 18, 105, 106, 13,
	88, 121, 0, 30, 0, 0, 0, 95, 29, 20,
	19, 0, 21, 0, 33, 0, 34, 0, 0, 22,
	0, 0, 0, 23, 24, 38, 45, 0, 25, 36,
	0, 0, 37, 0, 0, 27, 0, 32, 81, 82,
	332, 46, 48, 50, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 93, 0, 0, 0, 0, 143, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 0, 0, 0, 78, 42, 28, 47, 49,
	0, 0, 0, 55, 56, 0, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 92,
	77, 17, 1022, 35, 0, 63, 0, 97, 0, 0,
	0, 58, 57, 59, 60, 73, 120, 328, 0, 83,
	84, 72, 18, 105, 106, 13, 88, 121, 0, 30,
	0, 0, 0, 95, 29, 20, 19, 0, 21, 0,
	33, 0, 34, 0, 0, 22, 0, 0, 0, 23,
	24, 38, 45, 0, 25, 36, 0, 0, 37, 0,
	0, 27, 0, 32, 81, 82, 332, 46, 48, 50,
	0, 0, 0, 0, 52, 96, 0, 94, 110, 111,
	112, 107, 108, 0, 0, 0, 0, 0, 0, 93,
	0, 0, 0, 0, 143, 113, 109, 103, 0, 85,
	86, 87, 0, 0, 0, 0, 80, 53, 0, 0,
	0, 78, 42, 28, 47, 49, 0, 0, 0, 55,
	56, 0, 65, 66, 67, 68, 69, 70, 71, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 92, 77, 17, 1017, 35,
	0, 63, 0, 97, 0, 0, 0, 58, 57, 59,
	60, 73, 120, 328, 0, 83, 84, 72, 18, 105,
	106, 13, 88, 121, 0, 30, 0, 0, 0, 95,
	29, 20, 19, 0, 21, 0, 33, 0, 34, 0,
	0, 22, 0, 0, 0, 23, 24, 38, 45, 0,
	25, 36, 0, 0, 37, 0, 0, 27, 0, 32,
	81, 82, 332, 46, 48, 50, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 28,
	47, 49, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 17, 1001, 35, 0, 63, 0, 97,
	0, 0, 0, 58, 57, 59, 60, 73, 120, 328,
	0, 83, 84, 72, 18, 105, 106, 13, 88, 121,
	0, 30, 0, 0, 0, 95, 29, 20, 19, 0,
	21, 989, 33, 0, 34, 0, 0, 22, 0, 0,
	0, 23, 24, 38, 45, 0, 25, 36, 0, 0,
	37, 0, 0, 27, 0, 32, 81, 82, 332, 46,
	48, 50, 0, 0, 0, 0, 52, 96, 0, 94,
	110, 111, 112, 107, 108, 0, 0, 0, 0, 0,
	0, 93, 0, 0, 0, 0, 143, 113, 109, 103,
	0, 85, 86, 87, 0, 0, 0, 0, 80, 53,
	0, 0, 0, 78, 42, 28, 47, 49, 0, 0,
	0, 55, 56, 0, 65, 66, 67, 68, 69, 70,
	71, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 92, 77, 17,
	0, 35, 0, 63, 0, 97, 0, 0, 0, 58,
	57, 59, 60, 73, 120, 328, 0, 83, 84, 72,
	18, 105, 106, 13, 88, 121, 0, 30, 0, 0,
	0, 95, 29, 20, 19, 0, 21, 0, 33, 975,
	34, 0, 0, 22, 0, 0, 0, 23, 24, 38,
	45, 0, 25, 36, 0, 0, 37, 0, 0, 27,
	0, 32, 81, 82, 332, 46, 48, 50, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	42, 28, 47, 49, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 17, 0, 35, 0, 63,
	0, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 328, 0, 83, 84, 72, 18, 105, 106, 13,
	88, 121, 0, 30, 0, 0, 0, 95, 29, 20,
	19, 0, 21, 0, 33, 0, 34, 0, 0, 22,
	0, 0, 0, 23, 24, 38, 45, 0, 25, 36,
	0, 0, 37, 0, 0, 27, 0, 32, 81, 82,
	332, 46, 48, 50, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 93, 0, 0, 0, 0, 143, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 0, 0, 0, 78, 42, 28, 47, 49,
	0, 0, 0, 55, 56, 0, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 92,
	77, 17, 974, 35, 0, 63, 0, 97, 0, 0,
	0, 58, 57, 59, 60, 73, 120, 328, 0, 83,
	84, 72, 18, 105, 106, 13, 88, 121, 0, 30,
	0, 0, 0, 95, 29, 20, 19, 0, 21, 0,
	33, 0, 34, 0, 0, 22, 0, 0, 0, 23,
	24, 38, 45, 0, 25, 36, 0, 0, 37, 0,
	0, 27, 0, 32, 81, 82, 332, 46, 48, 50,
	0, 0, 0, 0, 52, 96, 0, 94, 110, 111,
	112, 107, 108, 0, 0, 0, 0, 0, 0, 93,
	0, 0, 0, 0, 143, 113, 109, 103, 0, 85,
	86, 87, 0, 0, 0, 0, 80, 53, 0, 0,
	0, 78, 42, 28, 47, 49, 0, 0, 0, 55,
	56, 0, 65, 66, 67, 68, 69, 70, 71, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 92, 77, 17, 953, 35,
	0, 63, 0, 97, 0, 0, 0, 58, 57, 59,
	60, 73, 120, 328, 0, 83, 84, 72, 18, 105,
	106, 13, 88, 121, 0, 30, 0, 0, 0, 95,
	29, 20, 19, 0, 21, 0, 33, 0, 34, 0,
	0, 22, 0, 0, 0, 23, 24, 38, 45, 0,
	25, 36, 0, 0, 37, 0, 0, 27, 0, 32,
	81, 82, 332, 46, 48, 50, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 28,
	47, 49, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 17, 952, 35, 0, 63, 0, 97,
	0, 0, 0, 58, 57, 59, 60, 73, 120, 328,
	0, 83, 84, 72, 18, 105, 106, 13, 88, 121,
	0, 30, 0, 0, 0, 95, 29, 20, 19, 0,
	21, 0, 33, 0, 34, 0, 0, 22, 0, 0,
	0, 23, 24, 38, 45, 0, 25, 36, 0, 0,
	37, 0, 0, 27, 0, 32, 81, 82, 332, 46,
	48, 50, 0, 0, 0, 0, 52, 96, 0, 94,
	110, 111, 112, 107, 108, 0, 0, 0, 0, 0,
	0, 93, 0, 0, 0, 0, 143, 113, 109, 103,
	0, 85, 86, 87, 0, 0, 0, 0, 80, 53,
	0, 0, 0, 78, 42, 28, 47, 49, 0, 0,
	0, 55, 56, 0, 65, 66, 67, 68, 69, 70,
	71, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 92, 77, 17,
	950, 35, 0, 63, 0, 97, 0, 0, 0, 58,
	57, 59, 60, 73, 120, 328, 0, 83, 84, 72,
	18, 105, 106, 13, 88, 121, 0, 30, 0, 0,
	0, 95, 29, 20, 19, 0, 21, 0, 33, 0,
	34, 887, 0, 22, 0, 0, 0, 23, 24, 38,
	45, 0, 25, 36, 0, 0, 37, 0, 0, 27,
	0, 32, 81, 82, 332, 46, 48, 50, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	42, 28, 47, 49, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 17, 0, 35, 0, 63,
	0, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 328, 0, 83, 84, 72, 18, 105, 106, 13,
	88, 121, 0, 30, 0, 0, 0, 95, 29, 20,
	19, 699, 21, 0, 33, 0, 34, 0, 0, 22,
	0, 0, 0, 23, 24, 38, 45, 0, 25, 36,
	0, 0, 37, 0, 0, 27, 0, 32, 81, 82,
	332, 46, 48, 50, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 93, 0, 0, 0, 0, 143, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 0, 0, 0, 78, 42, 28, 47, 49,
	0, 0, 0, 55, 56, 0, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 92,
	77, 17, 0, 35, 0, 63, 0, 97, 0, 0,
	0, 58, 57, 59, 60, 73, 120, 328, 0, 83,
	84, 72, 18, 105, 106, 13, 88, 121, 0, 30,
	0, 0, 0, 95, 29, 20, 19, 0, 21, 0,
	33, 0, 34, 0, 0, 22, 0, 0, 0, 23,
	24, 38, 45, 0, 25, 36, 0, 0, 37, 0,
	0, 27, 0, 32, 81, 82, 332, 46, 48, 50,
	0, 0, 0, 0, 52, 96, 0, 94, 110, 111,
	112, 107, 108, 0, 0, 0, 0, 0, 0, 93,
	0, 0, 0, 0, 143, 113, 109, 103, 0, 85,
	86, 87, 0, 0, 0, 0, 80, 53, 0, 0,
	0, 78, 42, 28, 47, 49, 0, 0, 0, 55,
	56, 0, 65, 66, 67, 68, 69, 70, 71, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 92, 77, 17, 563, 35,
	0, 63, 0, 97, 0, 0, 0, 58, 57, 59,
	60, 73, 120, 328, 0, 83, 84, 72, 18, 105,
	106, 13, 88, 121, 0, 30, 0, 0, 0, 95,
	29, 20, 19, 0, 21, 0, 33, 0, 34, 0,
	0, 22, 0, 0, 0, 23, 24, 38, 45, 0,
	25, 36, 0, 0, 37, 0, 0, 27, 0, 32,
	81, 82, 332, 46, 48, 50, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 28,
	47, 49, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 17, 327, 35, 0, 63, 0, 97,
	0, 0, 0, 58, 57, 59, 60, 73, 120, 328,
	0, 83, 84, 72, 18, 105, 106, 13, 88, 121,
	0, 30, 0, 0, 0, 95, 29, 20, 19, 0,
	21, 0, 33, 0, 34, 0, 0, 22, 0, 0,
	0, 23, 24, 38, 45, 0, 25, 36, 0, 0,
	37, 0, 0, 27, 0, 32, 81, 82, 332, 46,
	48, 50, 0, 0, 0, 0, 52, 96, 0, 94,
	110, 111, 112, 107, 108, 0, 0, 0, 0, 0,
	0, 93, 0, 0, 0, 0, 143, 113, 109, 103,
	0, 85, 86, 87, 0, 0, 0, 0, 80, 53,
	0, 0, 0, 78, 42, 28, 47, 49, 0, 0,
	0, 55, 56, 0, 65, 66, 67, 68, 69, 70,
	71, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 92, 77, 17,
	0, 35, 0, 63, 0, 97, 0, 0, 0, 58,
	57, 59, 60, 73, 120, 83, 84, 72, 18, 105,
	106, 13, 88, 121, 0, 30, 0, 0, 0, 95,
	29, 20, 19, 0, 21, 0, 33, 0, 34, 0,
	0, 22, 0, 0, 0, 23, 24, 38, 45, 0,
	25, 36, 0, 0, 37, 0, 0, 27, 0, 32,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 28,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 17, 0, 35, 947, 63, 0, 97,
	0, 0, 0, 58, 57, 59, 60, 73, 120, 83,
	84, 72, 18, 105, 106, 13, 88, 121, 0, 30,
	0, 0, 0, 95, 29, 20, 19, 0, 21, 0,
	33, 0, 34, 0, 0, 22, 0, 0, 0, 23,
	24, 38, 45, 0, 25, 36, 0, 0, 37, 0,
	0, 27, 0, 32, 81, 82, 0, 0, 0, 0,
	0, 0, 0, 0, 52, 96, 0, 94, 110, 111,
	112, 107, 108, 0, 0, 0, 0, 0, 0, 93,
	0, 0, 0, 0, 143, 113, 109, 103, 0, 85,
	86, 87, 0, 0, 0, 0, 80, 53, 0, 0,
	0, 78, 42, 28, 0, 0, 0, 0, 0, 55,
	56, 0, 65, 66, 67, 68, 69, 70, 71, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 92, 77, 17, 0, 35,
	921, 63, 0, 97, 0, 0, 0, 58, 57, 59,
	60, 73, 120, 83, 84, 72, 18, 105, 106, 13,
	88, 121, 0, 30, 0, 0, 0, 95, 29, 20,
	19, 0, 21, 0, 33, 0, 34, 0, 0, 22,
	0, 0, 0, 23, 24, 38, 45, 0, 25, 36,
	0, 0, 37, 0, 0, 27, 0, 32, 81, 82,
	0, 0, 0, 0, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 93, 0, 0, 0, 0, 143, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 0, 0, 0, 78, 42, 28, 0, 0,
	0, 0, 0, 55, 56, 0, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 92,
	77, 17, 0, 35, 722, 63, 0, 97, 0, 0,
	0, 58, 57, 59, 60, 73, 120, 83, 84, 72,
	18, 105, 106, 13, 88, 121, 0, 30, 0, 0,
	0, 95, 29, 20, 19, 0, 21, 0, 33, 0,
	34, 0, 0, 22, 0, 0, 0, 23, 24, 38,
	45, 0, 25, 36, 0, 0, 37, 0, 0, 27,
	0, 32, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	42, 28, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 17, 0, 35, 337, 63,
	0, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 83, 84, 72, 18, 105, 106, 13, 88, 121,
	0, 30, 0, 0, 0, 95, 29, 20, 19, 0,
	21, 0, 33, 0, 34, 0, 0, 22, 0, 0,
	0, 23, 24, 38, 45, 0, 25, 36, 0, 0,
	37, 0, 0, 27, 0, 32, 81, 82, 0, 0,
	0, 0, 0, 0, 0, 0, 52, 96, 0, 94,
	110, 111, 112, 107, 108, 0, 0, 0, 0, 0,
	0, 93, 0, 0, 0, 0, 143, 113, 109, 103,
	0, 85, 86, 87, 0, 0, 0, 0, 80, 53,
	0, 0, 0, 78, 42, 28, 0, 0, 0, 0,
	0, 55, 56, 0, 65, 66, 67, 68, 69, 70,
	71, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 92, 77, 17,
	0, 35, 334, 63, 0, 97, 0, 0, 0, 58,
	57, 59, 60, 73, 120, 83, 84, 72, 18, 105,
	106, 13, 88, 121, 0, 30, 0, 0, 0, 95,
	29, 20, 19, 0, 21, 0, 33, 0, 34, 0,
	0, 22, 0, 0, 0, 23, 24, 38, 45, 0,
	25, 36, 0, 0, 37, 0, 0, 27, 0, 32,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 28,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 83, 84, 72, 0, 105,
	106, 126, 88, 121, 0, 0, 0, 0, 0, 95,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 17, 0, 35, 0, 63, 45, 97,
	0, 0, 0, 58, 57, 59, 60, 73, 120, 0,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 489, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 148, 149,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 83, 84, 72, 0, 105,
	106, 126, 88, 121, 0, 0, 0, 0, 0, 95,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 0, 0, 0, 0, 63, 45, 97,
	0, 0, 488, 58, 57, 59, 60, 73, 120, 0,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 148, 149,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 83, 84, 72, 0, 105,
	106, 126, 88, 121, 0, 0, 0, 0, 0, 95,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 0, 0, 0, 0, 63, 45, 97,
	0, 0, 867, 58, 57, 59, 60, 73, 120, 0,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 148, 149,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 83, 84, 72, 0, 105,
	106, 126, 88, 121, 0, 0, 0, 0, 0, 95,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 0, 0, 0, 0, 63, 45, 97,
	0, 0, 630, 58, 57, 59, 60, 73, 120, 0,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 148, 149,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 83, 84, 72, 0, 105,
	106, 126, 88, 121, 0, 0, 0, 0, 0, 95,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 0, 0, 0, 0, 63, 45, 97,
	0, 0, 628, 58, 57, 59, 60, 73, 120, 0,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 148, 149,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 83, 84, 72, 0, 105,
	106, 126, 88, 121, 0, 0, 0, 0, 0, 95,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 0, 0, 0, 0, 63, 45, 97,
	0, 0, 292, 58, 57, 59, 60, 73, 120, 0,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 149,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 0, 0, 83, 84, 72,
	0, 105, 106, 126, 88, 121, 0, 0, 0, 0,
	0, 95, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 92, 77, 0, 0, 0, 0, 63, 431, 97,
	45, 0, 0, 58, 57, 59, 60, 73, 120, 0,
	0, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	148, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 83, 84, 72,
	0, 105, 106, 126, 88, 121, 0, 0, 0, 0,
	0, 95, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 0, 0, 0, 0, 63,
	45, 97, 0, 0, 407, 58, 57, 59, 60, 73,
	120, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	148, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 83, 84, 72,
	0, 105, 106, 126, 88, 121, 0, 0, 0, 0,
	0, 95, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 0, 0, 0, 388, 63,
	45, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	148, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 83, 84, 72,
	0, 105, 106, 126, 88, 121, 0, 0, 0, 0,
	0, 95, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 0, 0, 152, 0, 63,
	45, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	148, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 83, 84, 72,
	0, 105, 106, 126, 88, 121, 0, 0, 0, 0,
	0, 95, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 0, 0, 150, 0, 63,
	45, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	148, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 83, 84, 72,
	0, 105, 106, 126, 88, 121, 0, 0, 0, 0,
	0, 95, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 0, 0, 146, 0, 63,
	45, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	148, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 83, 84, 72,
	0, 105, 106, 126, 442, 121, 0, 0, 0, 0,
	0, 95, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 0, 0, 0, 0, 63,
	45, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	148, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 83, 84, 72,
	0, 105, 106, 126, 88, 121, 0, 0, 0, 0,
	0, 95, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 0, 0, 0, 0, 63,
	45, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	42, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 0, 0, 169,
	171, 170, 192, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 77, 795, 0, 0, 0, 63,
	0, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 167, 168, 179, 182, 183, 184, 185, 186, 187,
	189, 191, 0, 0, 669, 667, 668, 0, 0, 0,
	0, 858, 193, 173, 177, 176, 0, 0, 0, 0,
	0, 172, 0, 174, 178, 180, 181, 188, 190, 175,
	756, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 671, 670, 658, 664,
	665, 672, 673, 674, 675, 678, 679, 0, 0, 169,
	171, 170, 192, 0, 0, 654, 0, 680, 662, 656,
	655, 0, 0, 0, 0, 0, 661, 0, 663, 657,
	659, 660, 676, 677, 666, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 167, 168, 179, 182, 183, 184, 185, 186, 187,
	189, 191, 169, 171, 170, 192, 0, 0, 0, 0,
	0, 0, 193, 173, 177, 176, 0, 0, 0, 0,
	0, 172, 0, 174, 178, 180, 181, 188, 190, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 167, 168, 179, 182, 183, 184,
	185, 186, 187, 189, 191, 0, 0, 0, 753, 169,
	171, 170, 192, 0, 0, 193, 173, 177, 176, 0,
	0, 0, 0, 0, 172, 0, 174, 178, 180, 181,
	188, 190, 175, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 167, 168, 179, 182, 183, 184, 185, 186, 187,
	189, 191, 0, 0, 0, 709, 169, 171, 170, 192,
	0, 0, 193, 173, 177, 176, 0, 0, 0, 0,
	0, 172, 0, 174, 178, 180, 181, 188, 190, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 167, 168,
	179, 182, 183, 184, 185, 186, 187, 189, 191, 0,
	0, 0, 644, 169, 171, 170, 192, 0, 0, 193,
	173, 177, 176, 0, 0, 0, 0, 0, 172, 0,
	174, 178, 180, 181, 188, 190, 175, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 167, 168, 179, 182, 183,
	184, 185, 186, 187, 189, 191, 0, 0, 0, 641,
	169, 171, 170, 192, 0, 0, 193, 173, 177, 176,
	0, 0, 0, 0, 0, 172, 0, 174, 178, 180,
	181, 188, 190, 175, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 167, 168, 179, 182, 183, 184, 185, 186,
	187, 189, 191, 169, 171, 170, 192, 0, 0, 0,
	623, 0, 0, 193, 173, 177, 176, 0, 0, 0,
	0, 0, 172, 0, 174, 178, 180, 181, 188, 190,
	175, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 167, 168, 179, 182, 183,
	184, 185, 186, 187, 189, 191, 169, 171, 170, 192,
	0, 0, 0, 622, 0, 0, 193, 173, 177, 176,
	0, 0, 0, 0, 0, 172, 0, 174, 178, 180,
	181, 188, 190, 175, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 167, 168,
	179, 182, 183, 184, 185, 186, 187, 189, 191, 0,
	0, 0, 603, 169, 171, 170, 192, 0, 0, 193,
	173, 177, 176, 0, 0, 0, 0, 0, 172, 0,
	174, 178, 180, 181, 188, 190, 175, 476, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 167, 168, 179, 182, 183,
	184, 185, 186, 187, 189, 191, 169, 171, 170, 192,
	0, 554, 0, 0, 0, 0, 193, 173, 177, 176,
	0, 0, 0, 0, 0, 172, 0, 174, 178, 180,
	181, 188, 190, 175, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 167, 168,
	179, 182, 183, 184, 185, 186, 187, 189, 191, 169,
	171, 170, 192, 0, 0, 0, 0, 0, 0, 193,
	173, 177, 176, 0, 0, 0, 0, 0, 172, 0,
	174, 178, 180, 181, 188, 190, 175, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 405, 0, 0,
	0, 167, 168, 179, 182, 183, 184, 185, 186, 187,
	189, 191, 0, 0, 0, 0, 0, 0, 0, 429,
	0, 0, 193, 173, 177, 176, 169, 171, 170, 192,
	0, 172, 0, 174, 178, 180, 181, 188, 190, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 167, 168,
	179, 182, 183, 184, 185, 186, 187, 189, 191, 169,
	171, 170, 192, 0, 0, 0, 0, 0, 0, 193,
	173, 177, 176, 0, 0, 0, 0, 0, 172, 0,
	174, 178, 180, 181, 188, 190, 175, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 167, 168, 179, 182, 183, 184, 185, 186, 187,
	189, 191, 169, 171, 170, 192, 397, 0, 0, 0,
	0, 0, 193, 173, 177, 176, 0, 0, 0, 0,
	0, 172, 0, 174, 178, 180, 181, 188, 190, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 167, 168, 179, 182, 183, 184,
	185, 186, 187, 189, 191, 169, 171, 170, 192, 347,
	0, 0, 0, 0, 0, 193, 173, 177, 176, 0,
	0, 0, 0, 0, 172, 0, 174, 178, 180, 181,
	188, 190, 175, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 167, 168, 179,
	182, 183, 184, 185, 186, 187, 189, 191, 169, 171,
	170, 192, 346, 0, 0, 0, 0, 0, 193, 173,
	177, 176, 0, 0, 0, 0, 0, 172, 0, 174,
	178, 180, 181, 188, 190, 175, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 669, 667, 668,
	167, 168, 179, 182, 183, 184, 185, 186, 187, 189,
	191, 0, 0, 0, 0, 166, 0, 0, 0, 0,
	0, 193, 173, 177, 176, 0, 0, 0, 0, 0,
	172, 0, 174, 178, 180, 181, 188, 190, 175, 671,
	670, 658, 664, 665, 672, 673, 674, 675, 678, 679,
	169, 171, 170, 192, 0, 0, 0, 0, 654, 0,
	680, 662, 656, 655, 0, 0, 0, 0, 0, 661,
	0, 663, 657, 659, 660, 676, 677, 666, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	667, 668, 167, 168, 179, 182, 183, 184, 185, 186,
	187, 189, 191, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 193, 173, 177, 176, 0, 0, 0,
	0, 0, 172, 0, 174, 178, 180, 181, 188, 190,
	175, 671, 670, 658, 664, 665, 672, 673, 674, 675,
	678, 679, 171, 170, 192, 0, 0, 0, 0, 0,
	654, 0, 680, 662, 656, 655, 0, 0, 0, 0,
	0, 661, 0, 663, 657, 659, 660, 676, 677, 666,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 167, 168, 179, 182, 183, 184, 185,
	186, 187, 189, 191, 170, 192, 0, 0, 0, 0,
	0, 0, 0, 0, 193, 173, 177, 176, 0, 0,
	0, 0, 0, 172, 0, 174, 178, 180, 181, 188,
	190, 175, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 167, 168, 179, 182, 183, 184,
	185, 186, 187, 189, 191, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 193, 173, 177, 176, 0,
	0, 0, 0, 0, 172, 0, 174, 178, 180, 181,
	188, 190, 175, 671, 670, 658, 664, 665, 672, 673,
	674, 675, 678, 679, 192, 0, 0, 0, 0, 0,
	0, 0, 654, 0, 680, 662, 656, 655, 0, 0,
	0, 0, 0, 661, 0, 663, 657, 659, 660, 676,
	677, 666, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 192, 167, 168, 179, 182, 183, 184, 185,
	186, 187, 189, 191, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 173, 177, 176, 0, 0,
	0, 0, 0, 172, 0, 174, 178, 180, 181, 188,
	190, 175, 168, 179, 182, 183, 184, 185, 186, 187,
	189, 191, 192, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 173, 177, 176, 0, 0, 0, 0,
	0, 172, 0, 174, 178, 180, 181, 188, 190, 175,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 179, 182, 183, 184, 185, 186, 187,
	189, 191, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 173, 177, 176, 0, 0, 0, 0,
	0, 172, 0, 174, 178, 180, 181, 188, 190, 175,
	658, 664, 665, 672, 673, 674, 675, 678, 679, 192,
	0, 0, 0, 0, 0, 0, 0, 654, 0, 0,
	662, 656, 655, 0, 0, 0, 0, 0, 0, 0,
	663, 657, 659, 660, 676, 677, 666, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	179, 182, 183, 184, 185, 186, 187, 189, 191, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	173, 177, 176, 0, 0, 0, 0, 0, 0, 0,
	174, 178, 180, 181, 188, 190, 175, 658, 664, 665,
	672, 673, 674, 675, 678, 679, 0, 0, 0, 0,
	0, 0, 0, 0, 654, 0, 0, 662, 656, 655,
	0, 0, 0, 0, 0, 0, 0, 0, 657, 659,
	660, 676, 677, 666, 658, 664, 665, 672, 673, 674,
	675, 678, 679, 192, 0, 0, 0, 0, 0, 0,
	0, 654, 0, 0, 0, 656, 655, 0, 0, 0,
	0, 0, 0, 0, 0, 657, 659, 660, 676, 677,
	666, 105, 106, 126, 0, 0, 0, 0, 0, 0,
	0, 529, 0, 0, 179, 182, 183, 184, 185, 186,
	187, 189, 191, 0, 105, 106, 126, 0, 0, 0,
	0, 0, 0, 0, 529, 177, 176, 0, 0, 0,
	0, 0, 0, 0, 0, 178, 180, 181, 188, 190,
	175, 0, 0, 524, 0, 527, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 530, 0, 0,
	0, 0, 522, 113, 109, 523, 524, 0, 527, 110,
	111, 112, 107, 108, 0, 0, 0, 0, 0, 0,
	530, 233, 0, 0, 0, 522, 113, 109, 523, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 233, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 788, 536,
	0, 525, 0, 0, 0, 535, 534, 532, 533, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 536, 0, 525, 0, 0, 0, 535, 534,
	532, 533,
}
var yyPact = [...]int{

	-1000, -1000, 2453, -1000, -1000, -1000, -1000, -1000, 317, 508,
	616, 113, -1000, 335, -1000, -1000, 1012, -1000, 261, 261,
	5561, 315, 261, 6773, 6663, 6553, 403, 150, 897, 6883,
	-1000, 8071, 314, 313, 312, -1000, 441, 6883, 1004, 45,
	998, 992, 6883, -1000, -1000, -1000, -1000, 762, -1000, 751,
	-1000, 1813, 308, 6883, 493, 404, 404, 6883, 6883, 6883,
	6883, -1000, -1000, 7103, -1000, 6883, 6883, 6883, 6883, 6883,
	6883, 6883, 304, 6883, -1000, 183, 182, 948, 6883, 725,
	405, 303, 302, 6883, 6883, 299, 6883, 6883, -1000, 181,
	-1000, -1000, 942, 844, -1000, 179, 298, 6111, -1000, 177,
	176, -1000, 283, 965, 647, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 130, 138, -1000, 637, 263, -1000,
	439, -1000, 243, 371, -1000, 965, -1000, 98, 677, 610,
	-1000, 726, 965, -1000, 991, -1000, -54, 4481, 5407, 7103,
	5253, 828, 45, 564, 6883, 301, -1000, 8018, -1000, 799,
	-1000, 7965, -1000, 398, 2010, 8163, -1000, 88, -1000, -1000,
	300, 69, 45, -55, 60, 8163, -1000, 6883, 6883, 6883,
	6883, 6883, 6883, 6883, 6883, 6883, 6883, 6883, 6883, 6883,
	6883, 6883, 6883, 6883, 6883, 6883, 6883, 6883, 6883, 6883,
	6883, 6883, 405, 6443, 404, 6883, 990, -1000, 7912, 397,
	374, -1000, 746, 744, -1000, 1813, 7859, -1000, -1000, 6333,
	6883, 6883, 6883, 6883, 6883, 6883, 6883, 6883, 6883, 6883,
	6883, 6883, 237, -1000, -1000, -1000, -1000, -1000, 283, 541,
	965, 636, 632, -1000, -1000, 463, 463, 496, 463, 238,
	7792, 236, 463, 463, 463, 463, 463, 463, 463, -1000,
	6221, -1000, 463, 6883, 6883, 443, 733, 730, -1000, 271,
	6993, 404, 1334, 195, 263, 618, -1000, 524, 531, 965,
	708, 130, 138, 573, 6883, 6883, 8163, 8163, 6883, 8163,
	8163, 6883, 626, 733, 917, -1000, 830, 6883, 6111, 171,
	7, 7739, 404, 6883, 6883, 989, -1000, 1675, 283, 191,
	6883, 6883, 130, 439, 276, -1000, 6883, 396, -1000, -1000,
	2297, 283, -1000, 716, 50, -1000, 712, 965, -3, -1000,
	711, 965, 986, 662, -57, 8826, -1000, -1000, -1000, -1000,
	-1000, -1000, 292, -1000, -1000, -1000, -1000, -1000, 261, 290,
	395, -18, 8163, -1000, 394, 387, -1000, -1000, -1000, -1000,
	-1000, 150, -1000, 6883, -1000, -1000, 950, 288, 8826, -1000,
	6883, 8432, 8482, 8254, 1334, 8305, 8569, 8693, 1814, 35,
	35, 35, 496, 463, 496, 496, 342, 342, 700, 700,
	700, 700, 57, 57, 57, 57, -1000, 7686, 6883, 23,
	-1000, -1000, 1925, 812, 16, -71, 4325, -1000, -1000, 281,
	718, 727, 607, 438, 607, 6883, 1334, 282, 1334, 1334,
	1334, 1334, 1334, 1334, 1334, 1334, 1334, 1334, 1334, 1334,
	13, -1000, -1000, 278, 965, 283, 195, 195, 249, -1000,
	-1000, -1000, 164, 8163, 162, -1000, -1000, -1000, -1000, 939,
	981, 7629, 156, 413, 263, 139, -1000, -1000, 130, 138,
	-1000, 6883, -1000, -1000, 134, 965, 524, 195, 130, 134,
	-4, -1000, 1813, -1000, 1583, 7576, 7523, 152, -1000, -1000,
	-1000, 151, 234, -1000, -1000, 6001, 5891, -1000, -1000, 141,
	133, -1000, -1000, -9, 228, -1000, -1000, 1813, 404, 6883,
	-1000, 263, 263, -1000, -1000, 103, 7466, 263, 263, -1000,
	7409, -1000, 2141, -1000, -1000, -1000, -1000, 677, 979, 623,
	-1000, 610, 976, 611, -1000, 974, 8826, -1000, 8110, -1000,
	-1000, 524, 529, 965, 274, 8826, -1000, -1000, -1000, -1000,
	710, 571, 8826, 8826, 8826, 8826, 8826, 227, 551, 4637,
	4169, 386, 6883, 6883, 490, -1000, 892, -1000, -1000, 7352,
	-75, 718, -1000, 8163, 6883, 8394, 385, 404, 132, 132,
	5099, 973, 8826, 794, 718, 219, -30, -1000, 45, -1000,
	-1000, -1000, 524, 527, 965, 437, 607, -1000, -1000, -43,
	-1000, -1000, 1813, -1000, 405, -78, 237, 237, 283, -1000,
	-1000, 149, 704, 6883, -1000, 195, -1000, -1000, 99, -1000,
	-1000, -1000, -1000, -1000, -1000, 6883, -1000, -1000, 175, 131,
	-1000, 6883, 6883, 130, 7295, -1000, 524, -1000, -1000, -1000,
	6883, -1000, -1000, -1000, -1000, -1000, -1000, 7242, 404, 8163,
	404, -1000, -1000, -1000, 5671, -1000, -1000, 8163, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 971, -1000,
	-1000, 967, -1000, -1000, 8826, 8826, 8826, 8826, 8826, 8826,
	8826, 8826, 8826, 8826, 8826, 8826, 8826, 8826, 8826, 8826,
	8826, 8826, 8826, 8826, 8826, 8826, 8826, 8826, 8826, 8826,
	8803, 965, 524, 8826, 95, -39, 7187, 654, 898, 128,
	128, -53, -53, 1218, 384, -1000, 261, 5561, 509, 383,
	-1000, 381, 8163, -1000, 6883, 286, 467, 375, 884, -1000,
	8826, 211, 8394, -1000, -1000, 673, -1000, 404, 267, 673,
	-1000, -1000, -1000, -84, -1000, 780, 265, 209, 775, 718,
	518, 965, 524, -1000, -43, 1003, 607, 263, 6883, -1000,
	-10, 6883, 704, -1000, 76, 263, -1000, 7132, 704, 6883,
	6883, 73, 1927, -1000, 676, -1000, 5781, -1000, -1000, -1000,
	-1000, -1000, 1874, -53, -53, 128, 128, 128, 128, 8519,
	8643, 8606, 224, 224, -53, 1762, 8344, 8202, 102, -65,
	20, 20, 20, 20, -40, -40, -40, -40, 8826, 1163,
	524, 200, -1000, -1000, 8826, 8826, -1000, -1000, -1000, -1000,
	5561, -1000, 504, 261, 277, -1000, 6883, 1029, -1000, -1000,
	-1000, -1000, -1000, 372, -1000, 775, 198, 132, -1000, 237,
	189, 4013, 8826, -1000, 432, 607, 431, 430, 256, -1000,
	944, -1000, 524, 669, -1000, -1000, 941, -23, -1000, 799,
	621, -1000, 962, 607, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, 1334, -1000, 67, -1000, -1000, 410, -1000,
	66, 51, -1000, -1000, -1000, 195, 8163, 404, -1000, 1467,
	8826, -1000, 1711, 8110, -1000, 367, 250, -1000, 187, -1000,
	4637, -1000, 429, 4945, -1000, -13, 4945, 363, -1000, -1000,
	926, -1000, -1000, 166, -85, -1000, -26, -100, -1000, 959,
	45, -1000, -105, -81, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, 1467, 8826, -1000, -1000, 4637, 4791, 4637, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, 3857, 185, 3701, 3545, -27,
	-1000, 920, 8826, -1000, 890, 8826, -106, 958, 8826, -1000,
	607, -1000, 702, 8110, 4637, -1000, -1000, -1000, 3389, 3233,
	-1000, 425, -1000, -1000, -1000, 157, -1000, -1000, -107, -1000,
	8826, 254, -1000, -1000, 407, 702, -1000, 353, 347, 772,
	808, 570, -1000, 3077, -1000, 344, -1000, -1000, 846, 8826,
	-1000, 718, -1000, -1000, -1000, -1000, 607, 621, 954, 341,
	-1000, 2921, -1000, -1000, 158, -79, -1000, 953, -1000, -1000,
	-1000, 789, 334, 607, -1000, -1000, 789, -1000, 253, -1000,
	-1000, -1000, -1000, -1000, 607, 2765, 838, -1000, 104, 422,
	-1000, 2609, -1000,
}
var yyPgo = [...]int{

	0, 29, 1177, 22, 21, 1176, 49, 41, 39, 544,
	1175, 1172, 164, 217, 228, 180, 1362, 64, 51, 59,
	855, 1399, 1171, 33, 1170, 1169, 1157, 136, 1155, 40,
	37, 1154, 1152, 1151, 1149, 84, 1148, 1147, 20, 1145,
	28, 44, 38, 1139, 854, 36, 1137, 1, 1136, 1135,
	7, 1134, 52, 43, 42, 1132, 1131, 1128, 31, 1127,
	1126, 4, 1125, 1124, 1123, 16, 1122, 1121, 1120, 1115,
	48, 5, 1114, 1113, 1112, 1111, 1110, 2, 1109, 607,
	1108, 18, 202, 1100, 1099, 1098, 12, 1097, 1095, 6,
	19, 1093, 1092, 1091, 9, 50, 0, 1090, 1089, 1087,
	117, 1086, 1084, 642, 1083, 1082, 62, 8, 1076, 1075,
	1074, 1073, 14, 47, 1072, 1071, 1069, 1068, 1067, 1066,
	3, 1064, 23, 1063, 1062, 1060, 35, 1059, 1058, 1057,
	1056, 1055, 1054, 1052, 25, 1049, 1044, 1042, 24, 1038,
	15, 17, 1034, 34, 1033, 1031, 1029, 1028, 177, 13,
	1027, 1026,
}
var yyR1 = [...]int{

	0, 151, 95, 95, 96, 96, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 97, 97,
	6, 6, 6, 6, 98, 98, 7, 7, 7, 7,
	99, 99, 8, 8, 8, 8, 55, 55, 100, 100,
	26, 26, 26, 26, 26, 27, 27, 28, 28, 28,
	28, 28, 28, 28, 28, 28, 28, 28, 28, 28,
	28, 28, 28, 28, 28, 28, 28, 28, 28, 28,
	28, 28, 28, 28, 28, 117, 117, 60, 60, 118,
	118, 119, 119, 61, 115, 115, 58, 53, 54, 149,
	149, 150, 150, 62, 63, 63, 66, 66, 66, 66,
	91, 91, 2, 93, 93, 92, 92, 126, 126, 90,
	90, 89, 89, 89, 87, 87, 86, 86, 59, 59,
	116, 116, 84, 84, 84, 84, 113, 113, 113, 4,
	4, 88, 88, 109, 109, 110, 110, 56, 56, 57,
	57, 120, 120, 121, 121, 65, 65, 64, 64, 64,
	64, 82, 82, 82, 127, 127, 70, 70, 70, 70,
	101, 101, 29, 29, 29, 102, 102, 102, 102, 122,
	122, 67, 67, 67, 67, 69, 128, 128, 83, 83,
	129, 129, 130, 130, 71, 71, 72, 131, 131, 75,
	75, 74, 73, 73, 76, 76, 85, 85, 123, 123,
	124, 124, 132, 132, 77, 77, 77, 77, 77, 77,
	125, 125, 125, 125, 68, 68, 114, 114, 112, 112,
	111, 111, 138, 138, 136, 136, 137, 137, 137, 139,
	139, 44, 17, 17, 17, 17, 17, 17, 17, 17,
	17, 17, 17, 17, 17, 17, 17, 17, 17, 17,
	17, 17, 17, 17, 17, 17, 17, 17, 17, 17,
	17, 17, 17, 17, 17, 17, 17, 17, 17, 17,
	17, 17, 17, 17, 17, 17, 17, 17, 17, 17,
	17, 17, 17, 17, 17, 17, 17, 17, 17, 17,
	17, 17, 17, 17, 17, 17, 17, 17, 17, 17,
	17, 17, 17, 17, 17, 17, 52, 52, 52, 52,
	49, 49, 49, 49, 48, 48, 1, 94, 94, 108,
	108, 108, 108, 25, 25, 25, 25, 25, 25, 25,
	25, 13, 13, 13, 13, 47, 47, 47, 45, 45,
	43, 43, 146, 146, 145, 51, 51, 51, 133, 133,
	133, 81, 81, 9, 9, 9, 9, 9, 9, 9,
	9, 9, 9, 9, 9, 10, 30, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	37, 37, 37, 37, 31, 31, 31, 31, 31, 31,
	31, 134, 134, 3, 3, 135, 135, 135, 135, 16,
	16, 50, 50, 18, 19, 20, 21, 21, 147, 147,
	140, 142, 142, 78, 141, 141, 141, 42, 42, 46,
	46, 14, 24, 24, 22, 22, 22, 23, 23, 23,
	12, 12, 12, 11, 11, 15, 15, 143, 143, 144,
	144, 144, 41, 41, 148, 148, 107, 107, 40, 40,
	40, 106, 106, 105, 105, 105, 105, 105, 105, 105,
	105, 103, 103, 103, 103, 35, 35, 35, 35, 35,
	35, 35, 36, 36, 36, 39, 39, 39, 39, 39,
	39, 39, 39, 104, 104, 38, 38, 32, 32, 33,
	34,
}
var yyR2 = [...]int{

	0, 1, 2, 0, 1, 3, 1, 1, 1, 1,
	4, 3, 5, 4, 3, 4, 4, 2, 3, 1,
	1, 3, 2, 4, 3, 1, 1, 3, 2, 4,
	3, 1, 1, 3, 2, 4, 5, 4, 2, 0,
	1, 1, 1, 1, 4, 1, 2, 3, 5, 8,
	3, 5, 9, 3, 2, 3, 2, 3, 2, 3,
	3, 2, 3, 3, 3, 1, 2, 5, 8, 8,
	5, 1, 6, 3, 3, 0, 9, 0, 4, 1,
	0, 1, 2, 8, 1, 3, 1, 1, 1, 0,
	1, 0, 1, 9, 7, 6, 1, 2, 1, 2,
	0, 2, 1, 0, 2, 0, 2, 1, 3, 0,
	2, 1, 2, 4, 1, 4, 1, 4, 1, 4,
	3, 5, 3, 4, 4, 5, 0, 5, 4, 1,
	1, 1, 4, 0, 4, 0, 5, 0, 2, 0,
	3, 1, 0, 1, 3, 4, 6, 0, 1, 1,
	1, 2, 3, 3, 1, 3, 1, 1, 2, 2,
	3, 1, 1, 2, 4, 3, 5, 1, 3, 2,
	0, 3, 2, 1, 8, 3, 1, 3, 1, 3,
	0, 1, 1, 2, 2, 2, 3, 1, 3, 1,
	1, 3, 4, 3, 0, 1, 1, 3, 1, 1,
	0, 1, 1, 2, 1, 1, 1, 1, 1, 1,
	3, 5, 1, 3, 5, 4, 3, 1, 0, 1,
	3, 1, 2, 1, 4, 3, 2, 1, 1, 0,
	1, 3, 6, 3, 4, 6, 2, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 2,
	2, 2, 2, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	2, 2, 2, 2, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 1, 1, 4, 5, 4, 1, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 1, 1,
	1, 3, 2, 1, 9, 10, 2, 2, 4, 4,
	4, 4, 4, 4, 4, 3, 1, 0, 4, 3,
	4, 1, 2, 2, 4, 3, 4, 4, 4, 4,
	2, 1, 1, 3, 2, 1, 3, 2, 1, 1,
	4, 1, 2, 0, 2, 0, 2, 1, 0, 1,
	1, 0, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 3, 2, 3, 1, 1, 1, 1,
	3, 2, 4, 3, 1, 1, 1, 4, 3, 3,
	3, 3, 3, 3, 2, 2, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 4, 5, 2, 2, 3,
	1, 1, 3, 2, 1, 1, 1, 1, 3, 3,
	1, 0, 2, 0, 1, 5, 3, 3, 1, 1,
	1, 3, 3, 1, 1, 1, 5, 1, 2, 0,
	3, 4, 4, 1, 1, 1, 0, 1, 2, 3,
	3, 1, 4, 4, 1, 1, 1, 1, 2, 1,
	4, 4, 1, 1, 4, 0, 1, 1, 1, 4,
	4, 1, 1, 3, 1, 2, 3, 1, 1, 4,
	0, 0, 2, 5, 3, 3, 1, 6, 4, 4,
	2, 2, 2, 1, 2, 1, 4, 3, 3, 3,
	6, 3, 1, 1, 1, 4, 4, 4, 2, 2,
	4, 2, 2, 1, 3, 1, 1, 3, 3, 3,
	3,
}
var yyChk = [...]int{

	-1000, -151, -95, -5, 2, -27, -53, -54, 51, 79,
	44, -55, -28, 10, -62, -63, 38, 142, 7, 21,
	20, 23, 30, 34, 35, 39, -52, 46, 98, 19,
	14, -16, 48, 25, 27, 144, 40, 43, 36, -1,
	-66, -2, 97, -18, -17, 37, 52, 99, 53, 100,
	54, -21, 59, 92, -20, 104, 105, 153, 152, 154,
	155, -50, -44, 146, -39, 107, 108, 109, 110, 111,
	112, 113, 6, 156, -31, -49, -48, 141, 96, -22,
	91, 49, 50, 4, 5, 84, 85, 86, 11, -37,
	-34, -9, 140, 74, 62, 18, 60, 148, -23, -24,
	-25, -32, -96, 82, -13, 8, 9, 66, 67, 81,
	63, 64, 65, 80, -12, -148, -46, -14, -42, -11,
	157, 12, 146, -96, 142, 82, 10, -97, 37, 38,
	-6, -96, 82, 144, 158, 145, 10, -100, -50, 146,
	-50, -27, -1, 79, 146, -50, 144, -16, 97, 98,
	144, -16, 144, -17, -21, -16, 144, -101, -29, 12,
	157, -102, -1, 12, -114, -16, 144, 129, 130, 87,
	89, 88, 159, 151, 161, 167, 153, 152, 162, 131,
	163, 164, 132, 133, 134, 135, 136, 137, 165, 138,
	166, 139, 90, 150, 146, 146, 146, 142, -16, 10,
	-149, 151, 10, 10, -17, -21, -16, 52, 52, 160,
	117, 118, 119, 120, 121, 122, 123, 124, 125, 126,
	127, 128, 146, -16, 104, 105, -20, -21, -96, 79,
	82, -13, -14, 98, -20, -16, -16, -16, -16, -44,
	-16, -52, -16, -16, -16, -16, -16, -16, -16, -51,
	146, -50, -16, 148, 148, -133, 17, -103, -35, 12,
	76, 77, -16, 57, -45, -13, -43, -96, 79, 82,
	-23, -12, -148, -14, 146, 146, -16, -16, 146, -16,
	-16, 148, -103, 17, 17, 75, -103, 148, 146, -106,
	-105, -16, 151, 148, 148, 82, -82, 146, -96, 78,
	148, 142, -12, 157, 78, -82, 142, 147, 144, 142,
	-95, -96, 144, 158, -98, -7, -96, 82, -99, -8,
	-96, 82, 29, -96, 10, 160, -26, 143, 2, -27,
	-53, -54, 51, -27, 145, -88, -27, 145, 21, -149,
	-112, -111, -16, -84, 142, 145, 144, 144, 144, 144,
	144, 158, -18, 142, -21, 144, 158, -149, 160, 144,
	158, -16, -16, -16, -16, -16, -16, -16, -16, -16,
	-16, -16, -16, -16, -16, -16, -16, -16, -16, -16,
	-16, -16, -16, -16, -16, -16, -45, -16, 145, -115,
	-58, -21, -21, -17, -116, 10, -100, 144, 144, 10,
	146, -91, 55, -93, 55, 58, -16, 151, -16, -16,
	-16, -16, -16, -16, -16, -16, -16, -16, -16, -16,
	-107, -40, -21, 59, 82, -96, 78, 78, 147, 147,
	147, 147, -15, -16, -15, 141, -35, -35, 17, 148,
	57, -16, 11, -21, -143, -144, -42, -41, -12, -148,
	10, 142, -81, -82, 78, 82, -96, 57, -12, 78,
	-104, -38, -21, -17, -21, -16, -16, -15, 140, 75,
	75, -15, -106, 149, -3, 158, 58, -19, -21, -15,
	-15, 10, 147, -127, -52, -70, -17, -21, 151, 83,
	-82, -41, -42, 10, 52, -15, -16, -41, -42, 10,
	-16, 144, -95, 143, -82, -6, 144, 158, 29, -96,
	144, 158, 29, -96, 10, 29, 160, -30, -79, -9,
	-33, -96, 79, 82, 60, 148, -10, 62, -80, 18,
	74, -13, 154, 155, 153, 152, 146, 146, -109, -100,
	-100, -50, 144, 158, -113, 144, -113, 144, -29, -16,
	12, 146, -30, -16, 145, -16, 147, 158, 29, 29,
	147, 158, 160, 143, 146, -120, -121, -65, -64, 60,
	61, -47, -96, 79, 82, -92, 56, -47, 142, -126,
	-47, -17, -21, -21, 91, 147, 158, 146, -96, -139,
	-137, -136, -138, 148, -140, 57, 149, 149, -36, 10,
	13, 12, 10, 143, 143, 148, 143, -141, -78, -142,
	-82, 148, 142, -12, -16, -42, -96, -143, -42, 147,
	158, 147, 147, 147, 149, 149, 147, -16, 151, -16,
	151, 149, 149, 147, 158, 147, -19, -16, -82, -82,
	149, 143, -82, -82, 143, 143, -7, 10, 29, -8,
	10, 29, 10, -30, 148, 153, 152, 162, 131, 163,
	164, 159, 151, 161, 132, 133, 167, 88, 89, 87,
	130, 129, 134, 135, 136, 137, 165, 166, 138, 139,
	150, 82, -96, 146, -134, -135, -79, 17, 78, -79,
	-79, -79, -79, -79, 147, -56, 93, 94, -110, 22,
	144, -112, -16, 143, 32, 33, -113, 31, -113, 143,
	160, -120, -16, 144, -58, -89, -21, 151, 59, -89,
	-59, -27, 145, 10, -30, -117, 41, -120, 147, 158,
	-149, 82, -96, 142, -126, -122, 158, -45, 160, -40,
	-107, 148, -138, -140, -15, -143, 149, -16, -147, 148,
	148, -15, -16, 143, -146, -38, 58, -19, -19, -70,
	10, 10, -79, -79, -79, -79, -79, -79, -79, -79,
	-79, -79, -79, -79, -79, -79, -79, -79, -79, -79,
	-79, -79, -79, -79, -79, -79, -79, -79, 145, -79,
	-96, -134, 149, -3, 158, 58, 10, 52, 147, 144,
	-50, -27, -57, 93, 94, 144, 144, -16, -4, 145,
	144, 143, 144, 31, -30, 147, -90, 58, -21, 146,
	-90, -100, 160, -60, 42, 146, 147, -94, 44, -65,
	-150, 83, -96, -122, 143, -67, -123, -68, -69, -124,
	-132, 47, 38, 44, -77, 103, 102, 101, 98, 99,
	100, -47, -81, -16, 147, -15, 149, -141, 149, -140,
	-15, -15, 149, 143, -145, 57, -16, 151, 149, -79,
	145, 147, -79, -79, -27, 95, -50, 145, -112, -4,
	-100, 144, -94, 147, -89, -107, 147, 28, -30, 142,
	-47, 142, 142, 146, 12, 143, -125, 12, 144, 158,
	-1, -77, 10, -128, -47, 149, 143, 149, 149, -143,
	-19, -79, 58, 144, 145, -100, 147, -100, 142, -86,
	-27, 145, 147, -86, 144, -100, 12, -100, -100, -108,
	12, 151, 160, 144, 158, 160, 10, -149, 160, -83,
	158, 144, 142, -79, -100, -87, -27, 145, -100, -100,
	143, 147, 143, 143, 147, 158, 12, -30, 12, -30,
	160, 10, -30, -47, -129, -130, -71, -72, -73, -74,
	-75, -47, 10, -100, 143, 26, 142, 12, 151, 160,
	-30, 146, 143, -71, 144, 144, 45, 29, 78, 24,
	144, -100, 12, -30, -120, -131, -47, -76, -77, 10,
	144, 143, 147, 158, 10, -118, -119, -61, 41, -85,
	144, 142, -47, -61, 146, -100, -47, 143, 12, 147,
	142, -100, 143,
}
var yyDef = [...]int{

	3, -2, -2, 2, 6, 7, 8, 9, 0, 0,
	0, 0, 45, 4, 87, 88, 0, 39, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 331, 0,
	65, 0, 0, 0, 0, 71, 0, 0, 0, 89,
	0, 0, 303, 429, 430, 316, 96, 0, 98, 0,
	102, -2, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 283, 284, 0, 288, 0, 0, 0, 0, 0,
	0, 0, 345, 0, 298, 299, 300, 348, 0, 437,
	0, 0, 0, 0, 0, 0, 0, 0, 414, 415,
	416, 417, 0, 0, 420, 355, 0, 481, 454, 455,
	456, 410, -2, 0, 0, 353, 354, 356, 357, 358,
	359, 360, 361, 362, -2, 0, 459, 0, 0, 462,
	474, 463, 0, 0, 3, 0, 4, 0, 0, 0,
	19, 20, 0, 17, 0, 46, 0, 0, 0, 0,
	0, 0, 89, 0, 218, 0, 54, 0, 303, 331,
	56, 0, 58, 430, -2, 0, 61, 0, 161, 162,
	0, 0, 89, 167, 0, 217, 66, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 39, 0, 0,
	0, 90, 100, 103, -2, -2, 0, 97, 99, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 480, 236, 249, 251, 250, 435, 332, 0,
	0, 0, 0, 331, 252, 270, 271, 272, 273, 284,
	0, 0, 289, 290, 291, 292, 293, 294, 295, 296,
	0, 347, 297, 465, 465, 0, 349, 350, 493, 495,
	0, 0, 302, 0, 351, 338, 339, 332, 0, 0,
	341, -2, 0, 0, 0, 0, 508, 509, 0, 511,
	512, 465, 0, 0, 0, 364, 0, 465, 481, 0,
	423, 486, 0, 465, 465, 0, 323, 0, -2, 0,
	465, 0, -2, 475, 0, 330, 0, 0, 11, 3,
	0, -2, 14, 0, 0, 25, 26, 0, 0, 31,
	32, 0, 0, 22, 0, 0, 38, 47, 40, 41,
	42, 43, 0, 133, 39, 50, 131, 39, 0, 0,
	0, 219, 221, 53, 126, 126, 55, 57, 59, 60,
	62, 0, 163, 0, 433, 63, 0, 0, 0, 64,
	0, 253, 254, 255, 256, 257, 258, 259, 260, 261,
	262, 263, 264, 265, 266, 267, 268, 269, -2, -2,
	-2, -2, -2, -2, -2, -2, 282, 0, 0, 0,
	84, 86, -2, 430, 0, 0, 0, 73, 74, 0,
	-2, 105, 0, 0, 0, 0, 233, 0, 237, 238,
	239, 240, 241, 242, 243, 244, 245, 246, 247, 248,
	0, 477, 478, 0, 0, 334, 0, 0, 229, 431,
	432, 346, 0, 466, 0, 301, 494, 491, 492, 0,
	0, 0, 414, 0, 446, 467, 468, 471, 447, 0,
	472, 0, 231, 352, 0, 0, 334, 0, 458, 0,
	0, 513, -2, -2, -2, 0, 0, 0, 418, 363,
	419, 0, 0, 315, 482, 424, 0, 490, 434, 0,
	0, 5, 151, 0, 0, 154, -2, -2, 0, 0,
	325, 0, 449, -2, 520, 0, 0, 0, 450, -2,
	0, 10, 0, 13, 324, 18, 15, 0, 0, 28,
	16, 0, 0, 34, 21, 0, 0, 37, 366, 367,
	368, -2, 0, 0, 0, 421, 374, 375, 376, 355,
	0, 0, 0, 0, 0, 0, 0, 0, 137, -2,
	0, 0, 218, 0, 0, 126, 0, 126, 160, 0,
	165, -2, 168, 216, 0, 287, 0, 0, 0, 0,
	0, 0, 0, 75, -2, 0, 141, 143, 89, 148,
	149, 150, 335, 0, 0, 0, 0, 101, 170, 104,
	107, -2, -2, 234, 0, 0, 480, 480, 333, 285,
	230, 227, 228, 465, 223, 0, 311, 310, 0, 502,
	503, 504, 497, 498, 499, 0, 501, 439, 444, 445,
	443, 465, 0, 448, 0, 449, 333, 343, 450, 505,
	0, 506, 507, 510, 313, 312, 314, 484, 0, 485,
	0, 452, 453, 152, 0, 153, 158, 159, 326, 327,
	460, 461, 328, 329, 464, 12, 24, 27, 0, 30,
	33, 0, 23, 36, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, -2, 421, 0, 423, 428, 0, 0, 384,
	385, 407, 408, 0, 0, 48, 0, 0, 139, 0,
	51, 0, 220, 122, 0, 0, 0, 0, 0, 164,
	0, 0, 286, 67, 85, 109, 111, 0, 0, 109,
	70, 118, 39, 0, 120, 77, 0, 0, 317, 147,
	91, 0, 337, 170, 106, 200, 0, 351, 0, 476,
	0, 465, 226, 222, 0, 446, 496, 0, 436, 465,
	465, 0, 0, 473, 340, 514, 0, 488, 489, 155,
	29, 35, 0, 378, 379, 380, 381, 382, 383, 386,
	387, 388, 389, 390, 391, 392, 393, 394, 395, 396,
	-2, -2, -2, -2, -2, -2, -2, -2, 0, 0,
	-2, 0, 373, 422, 424, 0, 365, 519, 409, 44,
	0, 138, 0, 0, 0, 132, 218, 0, 39, 129,
	130, 123, 124, 0, 166, 317, 0, 0, 112, 480,
	0, 0, 0, 72, 0, 0, 0, 0, 0, 144,
	0, 92, 336, 200, 95, 169, 0, 0, 173, 0,
	-2, 199, 0, 0, 202, 204, 205, 206, 207, 208,
	209, 108, 235, 232, 479, 0, 225, 440, 0, 438,
	0, 0, 469, 470, 342, 0, 483, 0, 377, 405,
	0, 372, 426, 427, 134, 0, 0, 39, 0, 39,
	-2, 125, 0, 0, 110, 0, 0, 0, 121, 39,
	0, 39, 39, 0, 145, 94, 0, 212, 172, 0,
	89, 203, 0, 0, 176, 224, 500, 442, 441, 344,
	487, 406, 0, 49, 39, -2, 0, -2, 39, 68,
	116, 39, 113, 69, 119, 0, 0, 0, 0, 0,
	321, 0, 0, 171, 0, 0, 0, 0, 0, 175,
	0, 178, 180, 425, -2, 52, 114, 39, 0, 0,
	78, 0, 93, 304, 318, 0, 322, 146, 210, 213,
	0, 0, 215, 177, 0, 181, 182, 0, 0, 190,
	0, 0, -2, 0, 305, 0, 39, 319, 0, 0,
	214, -2, 179, 183, 184, 185, 0, 194, 0, 0,
	117, 0, 320, 211, 0, 186, 187, 0, -2, 191,
	115, 80, 0, 0, 192, 76, 79, 81, 0, 174,
	196, 39, 188, 82, 0, 0, 0, 197, 0, 0,
	39, 0, 83,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 154, 140, 3, 157, 164, 151, 3,
	146, 147, 162, 153, 158, 152, 167, 163, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 145, 144,
	165, 160, 166, 150, 156, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 148, 3, 149, 161, 3, 141, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 142, 159, 143, 155,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 9, 10, 11,
	12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
	22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
	32, 33, 34, 35, 36, 37, 38, 39, 40, 41,
	42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
	52, 53, 54, 55, 56, 57, 58, 59, 60, 61,
	62, 63, 64, 65, 66, 67, 68, 69, 70, 71,
	72, 73, 74, 75, 76, 77, 78, 79, 80, 81,
	82, 83, 84, 85, 86, 87, 88, 89, 90, 91,
	92, 93, 94, 95, 96, 97, 98, 99, 100, 101,
	102, 103, 104, 105, 106, 107, 108, 109, 110, 111,
	112, 113, 114, 115, 116, 117, 118, 119, 120, 121,
	122, 123, 124, 125, 126, 127, 128, 129, 130, 131,
	132, 133, 134, 135, 136, 137, 138, 139,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = true
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:281
		{
			yylex.(*Parser).rootNode = node.NewRoot(yyDollar[1].list)
			yylex.(*Parser).rootNode.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)

			if yylex.(*Parser).currentToken.Value == "\xff" {
				addMeta(yylex.(*Parser).rootNode, yylex.(*Parser).currentToken.Meta, meta.NodeEnd)
			}
		}
	case 2:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:295
		{
			if yyDollar[2].node != nil {
				yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 3:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:303
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:312
		{
			namePart := name.NewNamePart(yyDollar[1].token.Value)
			yyVAL.list = []node.Node{namePart}

			// save position
			namePart.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(namePart, yyDollar[1].token.Meta, meta.StringToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 5:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:325
		{
			namePart := name.NewNamePart(yyDollar[3].token.Value)
			yyVAL.list = append(yyDollar[1].list, namePart)

			// save position
			namePart.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NsSeparatorToken)
			addMeta(namePart, yyDollar[3].token.Meta, meta.StringToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 6:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:342
		{
			// error
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 7:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:349
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 8:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:355
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 9:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:361
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 10:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:367
		{
			yyVAL.node = stmt.NewHaltCompiler()

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.HaltCompilerToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 11:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:382
		{
			name := name.NewName(yyDollar[2].list)
			yyVAL.node = stmt.NewNamespace(name, nil)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NamespaceToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 12:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:397
		{
			name := name.NewName(yyDollar[2].list)
			yyVAL.node = stmt.NewNamespace(name, yyDollar[4].list)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NamespaceToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 13:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:413
		{
			yyVAL.node = stmt.NewNamespace(nil, yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NamespaceToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 14:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:427
		{
			yyVAL.node = stmt.NewUseList(nil, yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.UseToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 15:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:440
		{
			useType := node.NewIdentifier(yyDollar[2].token.Value)
			yyVAL.node = stmt.NewUseList(useType, yyDollar[3].list)

			// save position
			useType.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.UseToken)
			addMeta(useType, yyDollar[2].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 16:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:456
		{
			useType := node.NewIdentifier(yyDollar[2].token.Value)
			yyVAL.node = stmt.NewUseList(useType, yyDollar[3].list)

			// save position
			useType.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.UseToken)
			addMeta(useType, yyDollar[2].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 17:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:472
		{
			yyVAL.node = yyDollar[1].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 18:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:487
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:496
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 20:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:505
		{
			name := name.NewName(yyDollar[1].list)
			yyVAL.node = stmt.NewUse(nil, name, nil)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 21:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:516
		{
			name := name.NewName(yyDollar[1].list)
			alias := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewUse(nil, name, alias)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AsToken)
			addMeta(alias, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 22:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:533
		{
			name := name.NewName(yyDollar[2].list)
			yyVAL.node = stmt.NewUse(nil, name, nil)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 23:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:547
		{
			name := name.NewName(yyDollar[2].list)
			alias := node.NewIdentifier(yyDollar[4].token.Value)
			yyVAL.node = stmt.NewUse(nil, name, alias)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[2].list, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NsSeparatorToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.AsToken)
			addMeta(alias, yyDollar[4].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 24:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:568
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 25:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:577
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 26:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:586
		{
			name := name.NewName(yyDollar[1].list)
			yyVAL.node = stmt.NewUse(nil, name, nil)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 27:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:597
		{
			name := name.NewName(yyDollar[1].list)
			alias := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewUse(nil, name, alias)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AsToken)
			addMeta(alias, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 28:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:614
		{
			name := name.NewName(yyDollar[2].list)
			yyVAL.node = stmt.NewUse(nil, name, nil)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 29:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:628
		{
			name := name.NewName(yyDollar[2].list)
			alias := node.NewIdentifier(yyDollar[4].token.Value)
			yyVAL.node = stmt.NewUse(nil, name, alias)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[2].list, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NsSeparatorToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.AsToken)
			addMeta(alias, yyDollar[4].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 30:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:649
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 31:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:658
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:667
		{
			name := name.NewName(yyDollar[1].list)
			yyVAL.node = stmt.NewUse(nil, name, nil)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 33:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:678
		{
			name := name.NewName(yyDollar[1].list)
			alias := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewUse(nil, name, alias)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AsToken)
			addMeta(alias, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 34:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:695
		{
			name := name.NewName(yyDollar[2].list)
			yyVAL.node = stmt.NewUse(nil, name, nil)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 35:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:709
		{
			name := name.NewName(yyDollar[2].list)
			alias := node.NewIdentifier(yyDollar[4].token.Value)
			yyVAL.node = stmt.NewUse(nil, name, alias)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[2].list, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NsSeparatorToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.AsToken)
			addMeta(alias, yyDollar[4].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 36:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:730
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			constant := stmt.NewConstant(name, yyDollar[5].node, "")
			constList := yyDollar[1].node.(*stmt.ConstList)
			constList.Consts = append(constList.Consts, constant)
			yyVAL.node = yyDollar[1].node

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			constant.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeNodeListPosition(yyDollar[1].node, constList.Consts))

			// save comments
			addMeta(lastNode(constList.Consts), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(name, yyDollar[3].token.Meta, meta.IdentifierToken)
			addMeta(constant, yyDollar[4].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 37:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:750
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			constant := stmt.NewConstant(name, yyDollar[4].node, "")
			constList := []node.Node{constant}
			yyVAL.node = stmt.NewConstList(constList)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			constant.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[4].node))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, constList))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ConstToken)
			addMeta(name, yyDollar[2].token.Meta, meta.IdentifierToken)
			addMeta(constant, yyDollar[3].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 38:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:772
		{
			if yyDollar[2].node != nil {
				yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 39:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:780
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:790
		{
			// error
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:797
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:803
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:809
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 44:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:815
		{
			yyVAL.node = stmt.NewHaltCompiler()

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.HaltCompilerToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:834
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 46:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:840
		{
			label := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.node = stmt.NewLabel(label)

			// save position
			label.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(label, yyDollar[1].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.ColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 47:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:858
		{
			yyVAL.node = stmt.NewStmtList(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 48:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:871
		{
			yyVAL.node = stmt.NewIf(yyDollar[2].node, yyDollar[3].node, yyDollar[4].list, yyDollar[5].node)

			// save position
			if yyDollar[5].node != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[5].node))
			} else if len(yyDollar[4].list) > 0 {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[4].list))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))
			}

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IfToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 49:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:889
		{
			stmts := stmt.NewStmtList(yyDollar[4].list)
			yyVAL.node = stmt.NewAltIf(yyDollar[2].node, stmts, yyDollar[5].list, yyDollar[6].node)

			// save position
			stmts.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[4].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[8].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IfToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.ColonToken)
			addMeta(yyVAL.node, yyDollar[7].token.Meta, meta.EndifToken)
			addMeta(yyVAL.node, yyDollar[8].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 50:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:906
		{
			switch n := yyDollar[3].node.(type) {
			case *stmt.While:
				n.Cond = yyDollar[2].node
			case *stmt.AltWhile:
				n.Cond = yyDollar[2].node
			}

			yyVAL.node = yyDollar[3].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.WhileToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 51:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:925
		{
			yyVAL.node = stmt.NewDo(yyDollar[2].node, yyDollar[4].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DoToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.WhileToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 52:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php5/php5.y:939
		{
			switch n := yyDollar[9].node.(type) {
			case *stmt.For:
				n.Init = yyDollar[3].list
				n.Cond = yyDollar[5].list
				n.Loop = yyDollar[7].list
			case *stmt.AltFor:
				n.Init = yyDollar[3].list
				n.Cond = yyDollar[5].list
				n.Loop = yyDollar[7].list
			}

			yyVAL.node = yyDollar[9].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[9].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ForToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.ForInitSemicolonToken)
			addMeta(yyVAL.node, yyDollar[6].token.Meta, meta.ForCondSemicolonToken)
			addMeta(yyVAL.node, yyDollar[8].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 53:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:966
		{
			switch n := yyDollar[3].node.(type) {
			case *stmt.Switch:
				n.Cond = yyDollar[2].node
			case *stmt.AltSwitch:
				n.Cond = yyDollar[2].node
			default:
				panic("unexpected node type")
			}

			yyVAL.node = yyDollar[3].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.SwitchToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 54:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:987
		{
			yyVAL.node = stmt.NewBreak(nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.BreakToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 55:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1000
		{
			yyVAL.node = stmt.NewBreak(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.BreakToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 56:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1013
		{
			yyVAL.node = stmt.NewContinue(nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ContinueToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 57:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1026
		{
			yyVAL.node = stmt.NewContinue(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ContinueToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 58:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1039
		{
			yyVAL.node = stmt.NewReturn(nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ReturnToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 59:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1052
		{
			yyVAL.node = stmt.NewReturn(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ReturnToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 60:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1065
		{
			yyVAL.node = stmt.NewReturn(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ReturnToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 61:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1078
		{
			yyVAL.node = stmt.NewExpression(yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 62:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1090
		{
			yyVAL.node = stmt.NewGlobal(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.GlobalToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 63:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1103
		{
			yyVAL.node = stmt.NewStatic(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.StaticToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 64:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1116
		{
			yyVAL.node = stmt.NewEcho(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.EchoToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1129
		{
			yyVAL.node = stmt.NewInlineHtml(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.InlineHTMLToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 66:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1141
		{
			yyVAL.node = stmt.NewExpression(yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 67:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1153
		{
			yyVAL.node = stmt.NewUnset(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.UnsetToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseParenthesisToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 68:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:1168
		{
			if yyDollar[6].node == nil {
				switch n := yyDollar[8].node.(type) {
				case *stmt.Foreach:
					n.Expr = yyDollar[3].node
					n.Variable = yyDollar[5].node
				case *stmt.AltForeach:
					n.Expr = yyDollar[3].node
					n.Variable = yyDollar[5].node
				}
			} else {
				switch n := yyDollar[8].node.(type) {
				case *stmt.Foreach:
					n.Expr = yyDollar[3].node
					n.Key = yyDollar[5].node
					n.Variable = yyDollar[6].node
				case *stmt.AltForeach:
					n.Expr = yyDollar[3].node
					n.Key = yyDollar[5].node
					n.Variable = yyDollar[6].node
				}
			}

			yyVAL.node = yyDollar[8].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[8].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ForeachToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.AsToken)
			addMeta(yyVAL.node, yyDollar[7].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 69:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:1205
		{
			if yyDollar[6].node == nil {
				switch n := yyDollar[8].node.(type) {
				case *stmt.Foreach:
					n.Expr = yyDollar[3].node
					n.Variable = yyDollar[5].node
				case *stmt.AltForeach:
					n.Expr = yyDollar[3].node
					n.Variable = yyDollar[5].node
				}
			} else {
				switch n := yyDollar[8].node.(type) {
				case *stmt.Foreach:
					n.Expr = yyDollar[3].node
					n.Key = yyDollar[5].node
					n.Variable = yyDollar[6].node
				case *stmt.AltForeach:
					n.Expr = yyDollar[3].node
					n.Key = yyDollar[5].node
					n.Variable = yyDollar[6].node
				}
			}

			// save position
			yyVAL.node = yyDollar[8].node

			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[8].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ForeachToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.AsToken)
			addMeta(yyVAL.node, yyDollar[7].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 70:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1242
		{
			yyVAL.node = stmt.NewDeclare(yyDollar[3].list, yyDollar[5].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[5].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DeclareToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 71:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1256
		{
			yyVAL.node = stmt.NewNop()

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 72:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:1268
		{
			yyVAL.node = stmt.NewTry(yyDollar[3].list, yyDollar[5].list, yyDollar[6].node)

			// save position
			if yyDollar[6].node == nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[5].list))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[6].node))
			}

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.TryToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 73:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1286
		{
			yyVAL.node = stmt.NewThrow(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ThrowToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 74:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1299
		{
			label := node.NewIdentifier(yyDollar[2].token.Value)
			yyVAL.node = stmt.NewGoto(label)

			// save position
			label.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.GotoToken)
			addMeta(label, yyDollar[2].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 75:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1318
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 76:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php5/php5.y:1324
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[4].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			catch := stmt.NewCatch([]node.Node{yyDollar[3].node}, variable, yyDollar[7].list)
			yyVAL.list = append([]node.Node{catch}, yyDollar[9].list...)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			catch.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[8].token))

			// save comments
			addMeta(catch, yyDollar[1].token.Meta, meta.CatchToken)
			addMeta(catch, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(variable, yyDollar[4].token.Meta, meta.VariableToken)
			addMeta(catch, yyDollar[5].token.Meta, meta.CloseParenthesisToken)
			addMeta(catch, yyDollar[6].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(catch, yyDollar[8].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 77:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1349
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 78:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1355
		{
			yyVAL.node = stmt.NewFinally(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.FinallyToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 79:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1372
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 80:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1378
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 81:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1387
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 82:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1393
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 83:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:1402
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[4].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = stmt.NewCatch([]node.Node{yyDollar[3].node}, variable, yyDollar[7].list)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[8].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.CatchToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(variable, yyDollar[4].token.Meta, meta.VariableToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.CloseParenthesisToken)
			addMeta(yyVAL.node, yyDollar[6].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[8].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 84:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1426
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 85:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1432
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1444
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1453
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1462
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 89:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1471
		{
			yyVAL.token = nil
		}
	case 90:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1475
		{
			yyVAL.token = yyDollar[1].token
		}
	case 91:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1482
		{
			yyVAL.token = nil
		}
	case 92:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1486
		{
			yyVAL.token = yyDollar[1].token
		}
	case 93:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php5/php5.y:1493
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewFunction(name, yyDollar[2].token != nil, yyDollar[5].list, nil, yyDollar[8].list, "")

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[9].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.FunctionToken)
			if yyDollar[2].token != nil {
				addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AmpersandToken)
			}
			addMeta(name, yyDollar[3].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[6].token.Meta, meta.CloseParenthesisToken)
			addMeta(yyVAL.node, yyDollar[7].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[9].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 94:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line php5/php5.y:1518
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			switch n := yyDollar[1].node.(type) {
			case *stmt.Class:
				n.ClassName = name
				n.Stmts = yyDollar[6].list
				n.Extends = yyDollar[3].ClassExtends
				n.Implements = yyDollar[4].ClassImplements

			case *stmt.Trait:
				// TODO: is it possible that trait extend or implement
				n.TraitName = name
				n.Stmts = yyDollar[6].list
			}
			yyVAL.node = yyDollar[1].node

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[7].token))

			// save comments
			addMeta(name, yyDollar[2].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[7].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 95:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:1546
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			yyVAL.node = stmt.NewInterface(name, yyDollar[3].InterfaceExtends, yyDollar[5].list, "")

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[6].token))

			// save comments
			addMeta(name, yyDollar[2].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[6].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 96:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1566
		{
			yyVAL.node = stmt.NewClass(nil, nil, nil, nil, nil, nil, "")

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ClassToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 97:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1578
		{
			classModifier := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.node = stmt.NewClass(nil, []node.Node{classModifier}, nil, nil, nil, nil, "")

			// save position
			classModifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(classModifier, yyDollar[1].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.ClassToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 98:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1593
		{
			yyVAL.node = stmt.NewTrait(nil, nil, "")

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.TraitToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 99:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1605
		{
			classModifier := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.node = stmt.NewClass(nil, []node.Node{classModifier}, nil, nil, nil, nil, "")

			// save position
			classModifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(classModifier, yyDollar[1].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.ClassToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 100:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1623
		{
			yyVAL.ClassExtends = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 101:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1629
		{
			yyVAL.ClassExtends = stmt.NewClassExtends(yyDollar[2].node)

			// save position
			yyVAL.ClassExtends.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.ClassExtends, yyDollar[1].token.Meta, meta.ExtendsToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 102:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1644
		{
			yyVAL.token = yyDollar[1].token
		}
	case 103:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1651
		{
			yyVAL.InterfaceExtends = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 104:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1657
		{
			yyVAL.InterfaceExtends = stmt.NewInterfaceExtends(yyDollar[2].list)

			// save position
			yyVAL.InterfaceExtends.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))

			// save comments
			addMeta(yyVAL.InterfaceExtends, yyDollar[1].token.Meta, meta.ExtendsToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 105:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1672
		{
			yyVAL.ClassImplements = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 106:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1678
		{
			yyVAL.ClassImplements = stmt.NewClassImplements(yyDollar[2].list)

			// save position
			yyVAL.ClassImplements.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))

			// save comments
			addMeta(yyVAL.ClassImplements, yyDollar[1].token.Meta, meta.ImplementsToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 107:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1693
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 108:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1699
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 109:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1711
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 110:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1717
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DoubleArrowToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 111:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1729
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 112:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1735
		{
			yyVAL.node = expr.NewReference(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.AmpersandToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 113:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1747
		{
			yyVAL.node = expr.NewList(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ListToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 114:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1764
		{
			yyVAL.node = stmt.NewFor(nil, nil, nil, yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 115:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1773
		{
			stmtList := stmt.NewStmtList(yyDollar[2].list)
			yyVAL.node = stmt.NewAltFor(nil, nil, nil, stmtList)

			// save position
			stmtList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ColonToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.EndforToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 116:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1792
		{
			yyVAL.node = stmt.NewForeach(nil, nil, nil, yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 117:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1801
		{
			stmtList := stmt.NewStmtList(yyDollar[2].list)
			yyVAL.node = stmt.NewAltForeach(nil, nil, nil, stmtList)

			// save position
			stmtList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ColonToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.EndforeachToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 118:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1821
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 119:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1827
		{
			yyVAL.node = stmt.NewStmtList(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ColonToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.EnddeclareToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 120:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1845
		{
			name := node.NewIdentifier(yyDollar[1].token.Value)
			constant := stmt.NewConstant(name, yyDollar[3].node, "")
			yyVAL.list = []node.Node{constant}

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			constant.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			addMeta(name, yyDollar[1].token.Meta, meta.IdentifierToken)
			addMeta(constant, yyDollar[2].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 121:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1861
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			constant := stmt.NewConstant(name, yyDollar[5].node, "")
			yyVAL.list = append(yyDollar[1].list, constant)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			constant.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(name, yyDollar[3].token.Meta, meta.IdentifierToken)
			addMeta(constant, yyDollar[4].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 122:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1882
		{
			caseList := stmt.NewCaseList(yyDollar[2].list)
			yyVAL.node = stmt.NewSwitch(nil, caseList)

			// save position
			caseList.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(caseList, yyDollar[1].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(caseList, yyDollar[3].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 123:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1897
		{
			caseList := stmt.NewCaseList(yyDollar[3].list)
			yyVAL.node = stmt.NewSwitch(nil, caseList)

			// save position
			caseList.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(caseList, yyDollar[1].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(caseList, yyDollar[2].token.Meta, meta.SemiColonToken)
			addMeta(caseList, yyDollar[4].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 124:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1913
		{
			caseList := stmt.NewCaseList(yyDollar[2].list)
			yyVAL.node = stmt.NewAltSwitch(nil, caseList)

			// save position
			caseList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ColonToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.EndswitchToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 125:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1929
		{

			caseList := stmt.NewCaseList(yyDollar[3].list)
			yyVAL.node = stmt.NewAltSwitch(nil, caseList)

			// save position
			caseList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[3].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ColonToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SwitchSemicolonToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.EndswitchToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 126:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1951
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 127:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1957
		{
			_case := stmt.NewCase(yyDollar[3].node, yyDollar[5].list)
			yyVAL.list = append(yyDollar[1].list, _case)

			// save position
			_case.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[5].list))

			// save comments
			addMeta(_case, yyDollar[2].token.Meta, meta.CaseToken)
			addMeta(_case, yyDollar[4].token.Meta, meta.CaseSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 128:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1971
		{
			_default := stmt.NewDefault(yyDollar[4].list)
			yyVAL.list = append(yyDollar[1].list, _default)

			// save position
			_default.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[4].list))

			// save comments
			addMeta(_default, yyDollar[2].token.Meta, meta.DefaultToken)
			addMeta(_default, yyDollar[3].token.Meta, meta.CaseSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 129:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1989
		{
			yyVAL.token = yyDollar[1].token
		}
	case 130:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1993
		{
			yyVAL.token = yyDollar[1].token
		}
	case 131:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2001
		{
			yyVAL.node = stmt.NewWhile(nil, yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 132:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2010
		{
			stmtList := stmt.NewStmtList(yyDollar[2].list)
			yyVAL.node = stmt.NewAltWhile(nil, stmtList)

			// save position
			stmtList.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ColonToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.EndwhileToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 133:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2031
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 134:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2037
		{
			_elseIf := stmt.NewElseIf(yyDollar[3].node, yyDollar[4].node)
			yyVAL.list = append(yyDollar[1].list, _elseIf)

			// save position
			_elseIf.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[4].node))

			// save comments
			addMeta(_elseIf, yyDollar[2].token.Meta, meta.ElseifToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 135:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2054
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 136:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:2060
		{
			stmts := stmt.NewStmtList(yyDollar[5].list)
			_elseIf := stmt.NewAltElseIf(yyDollar[3].node, stmts)
			yyVAL.list = append(yyDollar[1].list, _elseIf)

			// save position
			stmts.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[5].list))
			_elseIf.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[5].list))

			// save comments
			addMeta(_elseIf, yyDollar[2].token.Meta, meta.ElseifToken)
			addMeta(_elseIf, yyDollar[4].token.Meta, meta.ColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 137:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2080
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 138:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2086
		{
			yyVAL.node = stmt.NewElse(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ElseToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 139:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2102
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 140:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2108
		{
			stmts := stmt.NewStmtList(yyDollar[3].list)
			yyVAL.node = stmt.NewAltElse(stmts)

			// save position
			stmts.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[3].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ElseToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.ColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 141:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2127
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 142:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2133
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 143:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2142
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 144:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2148
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 145:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2160
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[4].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = node.NewParameter(yyDollar[1].node, variable, nil, yyDollar[2].token != nil, yyDollar[3].token != nil)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			if yyDollar[1].node != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			} else if yyDollar[2].token != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[2].token, yyDollar[4].token))
			} else if yyDollar[3].token != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[3].token, yyDollar[4].token))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			}

			// save comments
			if yyDollar[2].token != nil {
				addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AmpersandToken)
			}
			if yyDollar[3].token != nil {
				addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.EllipsisToken)
			}
			addMeta(variable, yyDollar[4].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 146:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:2190
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[4].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = node.NewParameter(yyDollar[1].node, variable, yyDollar[6].node, yyDollar[2].token != nil, yyDollar[3].token != nil)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			if yyDollar[1].node != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[6].node))
			} else if yyDollar[2].token != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[6].node))
			} else if yyDollar[3].token != nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[6].node))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[4].token, yyDollar[6].node))
			}

			// save comments
			if yyDollar[2].token != nil {
				addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AmpersandToken)
			}
			if yyDollar[3].token != nil {
				addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.EllipsisToken)
			}
			addMeta(variable, yyDollar[4].token.Meta, meta.VariableToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 147:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2225
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 148:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2231
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 149:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2243
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 150:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2255
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 151:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2265
		{
			yyVAL.node = node.NewArgumentList(nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 152:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2278
		{
			yyVAL.node = node.NewArgumentList(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 153:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2291
		{
			arg := node.NewArgument(yyDollar[2].node, false, false)
			yyVAL.node = node.NewArgumentList([]node.Node{arg})

			// save position
			arg.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[2].node))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 154:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2310
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 155:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2316
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 156:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2328
		{
			yyVAL.node = node.NewArgument(yyDollar[1].node, false, false)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 157:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2337
		{
			yyVAL.node = node.NewArgument(yyDollar[1].node, false, false)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 158:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2346
		{
			yyVAL.node = node.NewArgument(yyDollar[2].node, false, true)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.AmpersandToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 159:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2358
		{
			yyVAL.node = node.NewArgument(yyDollar[2].node, true, false)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.EllipsisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 160:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2373
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 161:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2382
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 162:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2392
		{
			name := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			yyVAL.node = expr.NewVariable(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 163:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2406
		{
			yyVAL.node = expr.NewVariable(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DollarToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 164:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2418
		{
			yyVAL.node = expr.NewVariable(yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DollarToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 165:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2436
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[3].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			staticVar := stmt.NewStaticVar(variable, nil)
			yyVAL.list = append(yyDollar[1].list, staticVar)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			staticVar.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(variable, yyDollar[3].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 166:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:2454
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[3].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			staticVar := stmt.NewStaticVar(variable, yyDollar[5].node)
			yyVAL.list = append(yyDollar[1].list, staticVar)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			staticVar.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(variable, yyDollar[3].token.Meta, meta.VariableToken)
			addMeta(staticVar, yyDollar[4].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 167:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2473
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			staticVar := stmt.NewStaticVar(variable, nil)
			yyVAL.list = []node.Node{staticVar}

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			staticVar.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(variable, yyDollar[1].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 168:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2490
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			staticVar := stmt.NewStaticVar(variable, yyDollar[3].node)
			yyVAL.list = []node.Node{staticVar}

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			staticVar.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			addMeta(variable, yyDollar[1].token.Meta, meta.VariableToken)
			addMeta(staticVar, yyDollar[2].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 169:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2512
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 170:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2518
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 171:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2528
		{
			yyVAL.node = stmt.NewPropertyList(yyDollar[1].list, yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 172:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2540
		{
			yyVAL.node = yyDollar[1].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 173:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2552
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 174:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:2558
		{
			name := node.NewIdentifier(yyDollar[4].token.Value)
			yyVAL.node = stmt.NewClassMethod(name, yyDollar[1].list, yyDollar[3].token != nil, yyDollar[6].list, nil, yyDollar[8].node, "")

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			if yyDollar[1].list == nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[8].node))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListNodePosition(yyDollar[1].list, yyDollar[8].node))
			}

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.FunctionToken)
			if yyDollar[3].token != nil {
				addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.AmpersandToken)
			}
			addMeta(name, yyDollar[4].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[7].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 175:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2585
		{
			yyVAL.node = stmt.NewTraitUse(yyDollar[2].list, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.UseToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 176:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2600
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 177:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2606
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 178:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2618
		{
			yyVAL.node = stmt.NewNop()

			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 179:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2630
		{
			yyVAL.node = stmt.NewTraitAdaptationList(yyDollar[2].list)

			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 180:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2645
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 181:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2651
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 182:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2660
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 183:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2666
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 184:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2675
		{
			yyVAL.node = yyDollar[1].node

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 185:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2684
		{
			yyVAL.node = yyDollar[1].node

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 186:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2696
		{
			yyVAL.node = stmt.NewTraitUsePrecedence(yyDollar[1].node, yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeNodeListPosition(yyDollar[1].node, yyDollar[3].list))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.InsteadofToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 187:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2711
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 188:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2717
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2729
		{
			name := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.node = stmt.NewTraitMethodRef(nil, name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(name, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 190:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2743
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 191:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2752
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = stmt.NewTraitMethodRef(yyDollar[1].node, target)

			// save position
			target.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)
			addMeta(target, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 192:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2770
		{
			alias := node.NewIdentifier(yyDollar[4].token.Value)
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, yyDollar[3].node, alias)

			// save position
			alias.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AsToken)
			addMeta(alias, yyDollar[4].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 193:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2785
		{
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, yyDollar[3].node, nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AsToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 194:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2800
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 195:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2806
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 196:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2815
		{
			yyVAL.node = stmt.NewNop()

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.SemiColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 197:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2827
		{
			yyVAL.node = stmt.NewStmtList(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 198:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2843
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 199:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2849
		{
			modifier := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.list = []node.Node{modifier}

			// save position
			modifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(modifier, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 200:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2865
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 201:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2871
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 202:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2880
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 203:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2886
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 204:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2895
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 205:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2907
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 206:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2919
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 207:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2931
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 208:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2943
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 209:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2955
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 210:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2970
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[3].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			property := stmt.NewProperty(variable, nil, "")
			yyVAL.list = append(yyDollar[1].list, property)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			property.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(variable, yyDollar[3].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 211:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:2988
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[3].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			property := stmt.NewProperty(variable, yyDollar[5].node, "")
			yyVAL.list = append(yyDollar[1].list, property)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			property.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(variable, yyDollar[3].token.Meta, meta.VariableToken)
			addMeta(property, yyDollar[4].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3007
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			property := stmt.NewProperty(variable, nil, "")
			yyVAL.list = []node.Node{property}

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			property.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(variable, yyDollar[1].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 213:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3024
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			property := stmt.NewProperty(variable, yyDollar[3].node, "")
			yyVAL.list = []node.Node{property}

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			property.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			// save comments
			addMeta(variable, yyDollar[1].token.Meta, meta.VariableToken)
			addMeta(property, yyDollar[2].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 214:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:3045
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			constant := stmt.NewConstant(name, yyDollar[5].node, "")
			constList := yyDollar[1].node.(*stmt.ClassConstList)
			constList.Consts = append(constList.Consts, constant)
			yyVAL.node = yyDollar[1].node

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			constant.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))
			yyDollar[1].node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[5].node))

			// save comments
			addMeta(lastNode(constList.Consts), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(name, yyDollar[3].token.Meta, meta.IdentifierToken)
			addMeta(constant, yyDollar[4].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 215:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3065
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			constant := stmt.NewConstant(name, yyDollar[4].node, "")
			yyVAL.node = stmt.NewClassConstList(nil, []node.Node{constant})

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			constant.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[4].node))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ConstToken)
			addMeta(name, yyDollar[2].token.Meta, meta.IdentifierToken)
			addMeta(constant, yyDollar[3].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 216:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3086
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 217:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3095
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 218:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:3105
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 219:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3111
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 220:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3120
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 221:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3129
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 222:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3138
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].list...)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 223:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3144
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 224:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3153
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yyVAL.list = append(yyDollar[1].list, fetch)

			// save position
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			// save comments
			addMeta(fetch, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(fetch, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 225:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3167
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[2].node)
			yyVAL.list = []node.Node{fetch}

			// save position
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[2].node))

			// save comments
			addMeta(fetch, yyDollar[1].token.Meta, meta.OpenSquareBracket)
			addMeta(fetch, yyDollar[3].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 226:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3184
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].list...)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 227:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3190
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 228:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3196
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 229:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:3205
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 230:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3211
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 231:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3220
		{

			if yyDollar[3].node != nil {
				yyVAL.node = expr.NewNew(yyDollar[2].node, yyDollar[3].node.(*node.ArgumentList))
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))
			} else {
				yyVAL.node = expr.NewNew(yyDollar[2].node, nil)
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			}

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NewToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 232:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:3239
		{
			list := expr.NewList(yyDollar[3].list)
			yyVAL.node = assign.NewAssign(list, yyDollar[6].node)

			// save position
			list.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[6].node))

			// save comments
			addMeta(list, yyDollar[1].token.Meta, meta.ListToken)
			addMeta(list, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(list, yyDollar[4].token.Meta, meta.CloseParenthesisToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 233:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3256
		{
			yyVAL.node = assign.NewAssign(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.EqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 234:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3268
		{
			yyVAL.node = assign.NewReference(yyDollar[1].node, yyDollar[4].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.EqualToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.AmpersandToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 235:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:3281
		{
			var _new *expr.New

			if yyDollar[6].node != nil {
				_new = expr.NewNew(yyDollar[5].node, yyDollar[6].node.(*node.ArgumentList))
			} else {
				_new = expr.NewNew(yyDollar[5].node, nil)
			}
			yyVAL.node = assign.NewReference(yyDollar[1].node, _new)

			// save position
			if yyDollar[6].node != nil {
				_new.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[4].token, yyDollar[6].node))
			} else {
				_new.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[4].token, yyDollar[5].node))
			}
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, _new))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.EqualToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.AmpersandToken)
			addMeta(_new, yyDollar[4].token.Meta, meta.NewToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 236:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3307
		{
			yyVAL.node = expr.NewClone(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.CloneToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 237:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3319
		{
			yyVAL.node = assign.NewPlus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PlusEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 238:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3331
		{
			yyVAL.node = assign.NewMinus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.MinusEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 239:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3343
		{
			yyVAL.node = assign.NewMul(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.MulEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 240:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3355
		{
			yyVAL.node = assign.NewPow(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PowEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 241:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3367
		{
			yyVAL.node = assign.NewDiv(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.DivEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3379
		{
			yyVAL.node = assign.NewConcat(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.ConcatEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 243:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3391
		{
			yyVAL.node = assign.NewMod(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.ModEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 244:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3403
		{
			yyVAL.node = assign.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AndEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 245:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3415
		{
			yyVAL.node = assign.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OrEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3427
		{
			yyVAL.node = assign.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.XorEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 247:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3439
		{
			yyVAL.node = assign.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SlEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 248:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3451
		{
			yyVAL.node = assign.NewShiftRight(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SrEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 249:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3463
		{
			yyVAL.node = expr.NewPostInc(yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IncToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 250:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3475
		{
			yyVAL.node = expr.NewPreInc(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IncToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 251:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3487
		{
			yyVAL.node = expr.NewPostDec(yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.DecToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 252:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3499
		{
			yyVAL.node = expr.NewPreDec(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DecToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3511
		{
			yyVAL.node = binary.NewBooleanOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.BooleanOrToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 254:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3523
		{
			yyVAL.node = binary.NewBooleanAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.BooleanAndToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 255:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3535
		{
			yyVAL.node = binary.NewLogicalOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.LogicalOrToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 256:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3547
		{
			yyVAL.node = binary.NewLogicalAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.LogicalAndToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 257:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3559
		{
			yyVAL.node = binary.NewLogicalXor(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.LogicalXorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 258:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3571
		{
			yyVAL.node = binary.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.VerticalBarToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 259:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3583
		{
			yyVAL.node = binary.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AmpersandToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3595
		{
			yyVAL.node = binary.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.CaretToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 261:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3607
		{
			yyVAL.node = binary.NewConcat(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.DotToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 262:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3619
		{
			yyVAL.node = binary.NewPlus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PlusToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 263:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3631
		{
			yyVAL.node = binary.NewMinus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.MinusToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 264:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3643
		{
			yyVAL.node = binary.NewMul(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AsteriskToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 265:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3655
		{
			yyVAL.node = binary.NewPow(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PowToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 266:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3667
		{
			yyVAL.node = binary.NewDiv(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SlashToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 267:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3679
		{
			yyVAL.node = binary.NewMod(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PercentToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 268:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3691
		{
			yyVAL.node = binary.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SlToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 269:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3703
		{
			yyVAL.node = binary.NewShiftRight(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SrToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 270:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3715
		{
			yyVAL.node = expr.NewUnaryPlus(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.PlusToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 271:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3727
		{
			yyVAL.node = expr.NewUnaryMinus(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MinusToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 272:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3739
		{
			yyVAL.node = expr.NewBooleanNot(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ExclamationMarkToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 273:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3751
		{
			yyVAL.node = expr.NewBitwiseNot(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.TildeToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 274:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3763
		{
			yyVAL.node = binary.NewIdentical(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsIdenticalToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 275:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3775
		{
			yyVAL.node = binary.NewNotIdentical(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsNotIdenticalToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 276:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3787
		{
			yyVAL.node = binary.NewEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 277:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3799
		{
			yyVAL.node = binary.NewNotEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsNotEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 278:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3811
		{
			yyVAL.node = binary.NewSmaller(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.LessToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 279:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3823
		{
			yyVAL.node = binary.NewSmallerOrEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsSmallerOrEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 280:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3835
		{
			yyVAL.node = binary.NewGreater(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.GreaterToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 281:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3847
		{
			yyVAL.node = binary.NewGreaterOrEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsGreaterOrEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 282:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3859
		{
			yyVAL.node = expr.NewInstanceOf(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.InstanceofToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 283:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3871
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 284:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3877
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 285:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3883
		{
			yyVAL.node = yyDollar[2].node

			for _, n := range yyDollar[4].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					yyVAL.node = nn

				case *expr.MethodCall:
					nn.Variable = yyVAL.node
					yyVAL.node = nn
				}

				// save position
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, n))
			}

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 286:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:3912
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, yyDollar[3].node, yyDollar[5].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[5].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.QuestionMarkToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.ColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 287:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3925
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, nil, yyDollar[4].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.QuestionMarkToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.ColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 288:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3938
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 289:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3944
		{
			yyVAL.node = cast.NewInt(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IntCastToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 290:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3956
		{
			yyVAL.node = cast.NewDouble(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DoubleCastToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 291:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3968
		{
			yyVAL.node = cast.NewString(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.StringCastToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 292:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3980
		{
			yyVAL.node = cast.NewArray(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ArrayCastToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 293:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3992
		{
			yyVAL.node = cast.NewObject(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ObjectCastToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 294:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4004
		{
			yyVAL.node = cast.NewBool(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.BoolCastToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 295:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4016
		{
			yyVAL.node = cast.NewUnset(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.UnsetCastToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 296:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4028
		{
			var e *expr.Exit
			if yyDollar[2].node != nil {
				e = yyDollar[2].node.(*expr.Exit)
			} else {
				e = expr.NewExit(nil)
			}

			yyVAL.node = e

			if strings.EqualFold(yyDollar[1].token.Value, "die") {
				e.Die = true
			}

			// save position
			if yyDollar[2].node == nil {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			}

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ExitToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 297:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4055
		{
			yyVAL.node = expr.NewErrorSuppress(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.AtToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 298:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4067
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 299:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4073
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 300:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4079
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 301:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4085
		{
			yyVAL.node = expr.NewShellExec(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.BackquoteToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.BackquoteToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 302:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4098
		{
			yyVAL.node = expr.NewPrint(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.PrintToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 303:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4110
		{
			yyVAL.node = expr.NewYield(nil, nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.YieldToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 304:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php5/php5.y:4122
		{
			yyVAL.node = expr.NewClosure(yyDollar[4].list, yyDollar[6].ClosureUse, nil, yyDollar[8].list, false, yyDollar[2].token != nil, "")

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[9].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.FunctionToken)
			if yyDollar[2].token != nil {
				addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AmpersandToken)
			}
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.CloseParenthesisToken)
			addMeta(yyVAL.node, yyDollar[7].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[9].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 305:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line php5/php5.y:4141
		{
			yyVAL.node = expr.NewClosure(yyDollar[5].list, yyDollar[7].ClosureUse, nil, yyDollar[9].list, true, yyDollar[3].token != nil, "")

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[10].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.StaticToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.FunctionToken)
			if yyDollar[3].token != nil {
				addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.AmpersandToken)
			}
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[6].token.Meta, meta.CloseParenthesisToken)
			addMeta(yyVAL.node, yyDollar[8].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[10].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 306:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4164
		{
			yyVAL.node = expr.NewYield(nil, yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.YieldToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 307:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4176
		{
			yyVAL.node = expr.NewYield(nil, yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.YieldToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 308:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4188
		{
			yyVAL.node = expr.NewYield(yyDollar[2].node, yyDollar[4].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.YieldToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.DoubleArrowToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 309:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4201
		{
			yyVAL.node = expr.NewYield(yyDollar[2].node, yyDollar[4].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.YieldToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.DoubleArrowToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 310:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4217
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 311:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4230
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 312:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4243
		{
			str := scalar.NewString(yyDollar[1].token.Value)
			yyVAL.node = expr.NewArrayDimFetch(str, yyDollar[3].node)

			// save position
			str.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(str, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 313:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4258
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 314:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4274
		{
			yyVAL.node = expr.NewArray(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ArrayToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 315:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4288
		{
			yyVAL.node = expr.NewShortArray(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 316:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4304
		{
			yyVAL.token = yyDollar[1].token
		}
	case 317:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:4311
		{
			yyVAL.ClosureUse = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 318:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4317
		{
			yyVAL.ClosureUse = expr.NewClosureUse(yyDollar[3].list)

			yyVAL.ClosureUse.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 319:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4328
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[3].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.list = append(yyDollar[1].list, variable)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(variable, yyDollar[3].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 320:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4344
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[4].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			reference := expr.NewReference(variable)
			yyVAL.list = append(yyDollar[1].list, reference)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			reference.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[3].token, yyDollar[4].token))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(reference, yyDollar[3].token.Meta, meta.VariableToken)
			addMeta(variable, yyDollar[4].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 321:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4363
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.list = []node.Node{variable}

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(variable, yyDollar[1].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 322:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4378
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[2].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			reference := expr.NewReference(variable)
			yyVAL.list = []node.Node{reference}

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			reference.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(reference, yyDollar[1].token.Meta, meta.VariableToken)
			addMeta(variable, yyDollar[2].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 323:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4399
		{
			name := name.NewName(yyDollar[1].list)
			yyVAL.node = expr.NewFunctionCall(name, yyDollar[2].node.(*node.ArgumentList))

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(name, yyDollar[2].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 324:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4410
		{
			funcName := name.NewRelative(yyDollar[3].list)
			yyVAL.node = expr.NewFunctionCall(funcName, yyDollar[4].node.(*node.ArgumentList))

			// save position
			funcName.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(funcName, yyDollar[4].node))

			// save comments
			addMeta(funcName, yyDollar[1].token.Meta, meta.NamespaceToken)
			addMeta(funcName, yyDollar[2].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 325:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4425
		{
			funcName := name.NewFullyQualified(yyDollar[2].list)
			yyVAL.node = expr.NewFunctionCall(funcName, yyDollar[3].node.(*node.ArgumentList))

			// save position
			funcName.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(funcName, yyDollar[3].node))

			// save comments
			addMeta(funcName, yyDollar[1].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 326:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4439
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 327:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4451
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 328:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4463
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 329:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4475
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 330:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4487
		{
			yyVAL.node = expr.NewFunctionCall(yyDollar[1].node, yyDollar[2].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[2].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 331:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4499
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 332:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4511
		{
			yyVAL.node = name.NewName(yyDollar[1].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 333:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4520
		{
			yyVAL.node = name.NewRelative(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NamespaceToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 334:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4533
		{
			yyVAL.node = name.NewFullyQualified(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 335:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4548
		{
			yyVAL.node = name.NewName(yyDollar[1].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 336:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4557
		{
			yyVAL.node = name.NewRelative(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NamespaceToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 337:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4570
		{
			yyVAL.node = name.NewFullyQualified(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 338:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4585
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 339:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4591
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 340:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4600
		{
			yyVAL.node = yyDollar[1].node

			// save comments
			addMeta(yyDollar[3].list[0], yyDollar[2].token.Meta, meta.ObjectOperatorToken)

			for _, n := range yyDollar[3].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn
				}
			}

			for _, n := range yyDollar[4].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn
				}
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 341:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4637
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 342:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4647
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].list...)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 343:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:4653
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 344:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4663
		{
			yyVAL.list = yyDollar[2].list

			// save comments
			addMeta(yyDollar[2].list[0], yyDollar[1].token.Meta, meta.ObjectOperatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 345:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:4675
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 346:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4681
		{
			yyVAL.node = expr.NewExit(nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 347:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4694
		{
			yyVAL.node = expr.NewExit(yyDollar[1].node)

			// save position
			if yylex.(*Parser).currentToken.Value == ")" {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yylex.(*Parser).currentToken))
			} else {
				yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 348:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:4710
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 349:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4716
		{
			yyVAL.list = []node.Node{scalar.NewEncapsedStringPart(yyDollar[1].token.Value)}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 350:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4722
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 351:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:4731
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 352:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4737
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 353:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4746
		{
			yyVAL.node = scalar.NewLnumber(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.LnumberToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 354:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4758
		{
			yyVAL.node = scalar.NewDnumber(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DnumberToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 355:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4770
		{
			yyVAL.node = scalar.NewString(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ConstantEncapsedStringToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 356:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4782
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MagicConstantToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 357:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4794
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MagicConstantToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 358:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4806
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MagicConstantToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 359:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4818
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MagicConstantToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 360:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4830
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MagicConstantToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 361:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4842
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MagicConstantToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 362:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4854
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MagicConstantToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 363:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4866
		{
			encapsed := scalar.NewEncapsedStringPart(yyDollar[2].token.Value)
			yyVAL.node = scalar.NewHeredoc(yyDollar[1].token.Value, []node.Node{encapsed})

			// save position
			encapsed.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.StartHeredocToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 364:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4880
		{
			yyVAL.node = scalar.NewHeredoc(yyDollar[1].token.Value, nil)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.StartHeredocToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 365:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4895
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)

			// save position
			target.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)
			addMeta(target, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 366:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4913
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 367:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4922
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 368:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4928
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 369:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:4934
		{
			name := name.NewName(yyDollar[1].list)
			yyVAL.node = expr.NewConstFetch(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(name))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 370:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4945
		{
			name := name.NewRelative(yyDollar[3].list)
			yyVAL.node = expr.NewConstFetch(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))

			// save comments
			addMeta(name, yyDollar[1].token.Meta, meta.NamespaceToken)
			addMeta(name, yyDollar[2].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 371:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:4960
		{
			name := name.NewFullyQualified(yyDollar[2].list)
			yyVAL.node = expr.NewConstFetch(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))

			// save comments
			addMeta(name, yyDollar[1].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 372:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:4974
		{
			yyVAL.node = expr.NewArray(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ArrayToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 373:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:4988
		{
			yyVAL.node = expr.NewShortArray(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 374:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5001
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 375:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5007
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MagicConstantToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 376:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5019
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 377:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:5028
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 378:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5041
		{
			yyVAL.node = binary.NewPlus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PlusToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 379:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5053
		{
			yyVAL.node = binary.NewMinus(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.MinusToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 380:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5065
		{
			yyVAL.node = binary.NewMul(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AsteriskToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 381:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5077
		{
			yyVAL.node = binary.NewPow(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PowToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 382:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5089
		{
			yyVAL.node = binary.NewDiv(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SlashToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 383:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5101
		{
			yyVAL.node = binary.NewMod(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PercentToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 384:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:5113
		{
			yyVAL.node = expr.NewBooleanNot(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.ExclamationMarkToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 385:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:5125
		{
			yyVAL.node = expr.NewBitwiseNot(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.TildeToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 386:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5137
		{
			yyVAL.node = binary.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.VerticalBarToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 387:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5149
		{
			yyVAL.node = binary.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.AmpersandToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 388:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5161
		{
			yyVAL.node = binary.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.CaretToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 389:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5173
		{
			yyVAL.node = binary.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SlToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 390:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5185
		{
			yyVAL.node = binary.NewShiftRight(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.SrToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 391:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5197
		{
			yyVAL.node = binary.NewConcat(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.DotToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 392:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5209
		{
			yyVAL.node = binary.NewLogicalXor(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.LogicalXorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 393:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5221
		{
			yyVAL.node = binary.NewLogicalAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.LogicalAndToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 394:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5233
		{
			yyVAL.node = binary.NewLogicalOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.LogicalOrToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 395:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5245
		{
			yyVAL.node = binary.NewBooleanAnd(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.BooleanAndToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 396:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5257
		{
			yyVAL.node = binary.NewBooleanOr(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.BooleanOrToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 397:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5269
		{
			yyVAL.node = binary.NewIdentical(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsIdenticalToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 398:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5281
		{
			yyVAL.node = binary.NewNotIdentical(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsNotIdenticalToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 399:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5293
		{
			yyVAL.node = binary.NewEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 400:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5305
		{
			yyVAL.node = binary.NewNotEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsNotEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 401:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5317
		{
			yyVAL.node = binary.NewSmaller(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.LessToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 402:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5329
		{
			yyVAL.node = binary.NewGreater(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.GreaterToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 403:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5341
		{
			yyVAL.node = binary.NewSmallerOrEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsSmallerOrEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 404:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5353
		{
			yyVAL.node = binary.NewGreaterOrEqual(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.IsGreaterOrEqualToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 405:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:5365
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, nil, yyDollar[4].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.QuestionMarkToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.ColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 406:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:5378
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, yyDollar[3].node, yyDollar[5].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[5].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.QuestionMarkToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.ColonToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 407:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:5391
		{
			yyVAL.node = expr.NewUnaryPlus(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.PlusToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 408:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:5403
		{
			yyVAL.node = expr.NewUnaryMinus(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MinusToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 409:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5415
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 410:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5428
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 411:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5434
		{
			name := name.NewName(yyDollar[1].list)
			yyVAL.node = expr.NewConstFetch(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(name))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 412:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5445
		{
			name := name.NewRelative(yyDollar[3].list)
			yyVAL.node = expr.NewConstFetch(name)
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(name))

			// save comments
			addMeta(name, yyDollar[1].token.Meta, meta.NamespaceToken)
			addMeta(name, yyDollar[2].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 413:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:5458
		{
			name := name.NewFullyQualified(yyDollar[2].list)
			yyVAL.node = expr.NewConstFetch(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(name))

			// save comments
			addMeta(name, yyDollar[1].token.Meta, meta.NsSeparatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 414:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5475
		{
			name := node.NewIdentifier(yyDollar[1].token.Value)
			yyVAL.node = expr.NewVariable(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(name, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 415:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5489
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 416:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5495
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 417:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5501
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 418:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5507
		{
			yyVAL.node = scalar.NewEncapsed(yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DoubleQuoteToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 419:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5519
		{
			yyVAL.node = scalar.NewHeredoc(yyDollar[1].token.Value, yyDollar[2].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.StartHeredocToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 420:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5531
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.MagicConstantToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 421:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:5546
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 422:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:5552
		{
			yyVAL.list = yyDollar[1].list

			// save comments
			if yyDollar[2].token != nil {
				addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 423:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:5566
		{
			yyVAL.token = nil
		}
	case 424:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5570
		{
			yyVAL.token = yyDollar[1].token
		}
	case 425:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:5577
		{
			arrayItem := expr.NewArrayItem(yyDollar[3].node, yyDollar[5].node)
			yyVAL.list = append(yyDollar[1].list, arrayItem)

			// save position
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[3].node, yyDollar[5].node))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(arrayItem, yyDollar[4].token.Meta, meta.DoubleArrowToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 426:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5591
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[3].node)
			yyVAL.list = append(yyDollar[1].list, arrayItem)

			// save position
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 427:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5604
		{
			arrayItem := expr.NewArrayItem(yyDollar[1].node, yyDollar[3].node)
			yyVAL.list = []node.Node{arrayItem}

			// save position
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(arrayItem, yyDollar[2].token.Meta, meta.DoubleArrowToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 428:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5617
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[1].node)
			yyVAL.list = []node.Node{arrayItem}

			// save position
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 429:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5630
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 430:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5636
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 431:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5645
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 432:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5655
		{
			yyVAL.node = yyDollar[2].node

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 433:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5669
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 434:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5679
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 435:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5688
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 436:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:5697
		{
			yyVAL.node = yyDollar[1].node

			if yyDollar[4].list != nil {
				yyDollar[4].list[0].(*expr.MethodCall).Method = yyDollar[3].list[len(yyDollar[3].list)-1].(*expr.PropertyFetch).Property
				yyDollar[3].list = append(yyDollar[3].list[:len(yyDollar[3].list)-1], yyDollar[4].list...)
			}

			// save comments
			addMeta(yyDollar[3].list[0], yyDollar[2].token.Meta, meta.ObjectOperatorToken)

			for _, n := range yyDollar[3].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					nn.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					nn.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn

				case *expr.MethodCall:
					nn.Variable = yyVAL.node
					nn.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn
				}
			}

			for _, n := range yyDollar[5].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					nn.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					nn.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn

				case *expr.MethodCall:
					nn.Variable = yyVAL.node
					nn.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yyVAL.node = nn
				}
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 437:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5749
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 438:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:5758
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].list...)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 439:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:5764
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 440:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5774
		{
			if yyDollar[3].list != nil {
				yyDollar[3].list[0].(*expr.MethodCall).Method = yyDollar[2].list[len(yyDollar[2].list)-1].(*expr.PropertyFetch).Property
				yyDollar[2].list = append(yyDollar[2].list[:len(yyDollar[2].list)-1], yyDollar[3].list...)
			}

			yyVAL.list = yyDollar[2].list

			// save comments
			addMeta(yyDollar[2].list[0], yyDollar[1].token.Meta, meta.ObjectOperatorToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 441:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:5791
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yyVAL.list = append(yyDollar[1].list, fetch)

			// save position
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			// save comments
			addMeta(fetch, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(fetch, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 442:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:5805
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yyVAL.list = []node.Node{yyDollar[1].node, fetch}

			// save position
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			// save comments
			addMeta(fetch, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(fetch, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 443:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5822
		{
			yyVAL.node = expr.NewMethodCall(nil, nil, yyDollar[1].node.(*node.ArgumentList))

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 444:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5834
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 445:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5840
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 446:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:5846
		{
			yyVAL.list = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 447:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5855
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 448:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:5861
		{
			yyDollar[1].simpleIndirectReference.last.SetVarName(yyDollar[2].node)

			for _, n := range yyDollar[1].simpleIndirectReference.all {
				n.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(n, yyDollar[2].node))
			}

			yyVAL.node = yyDollar[1].simpleIndirectReference.all[0]

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 449:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5876
		{
			yyVAL.node = expr.NewStaticPropertyFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 450:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:5888
		{
			yyVAL.node = expr.NewStaticPropertyFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 451:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5903
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 452:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:5912
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 453:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:5925
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 454:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5941
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 455:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5947
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 456:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5953
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 457:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5963
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 458:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:5969
		{
			yyDollar[1].simpleIndirectReference.last.SetVarName(yyDollar[2].node)

			for _, n := range yyDollar[1].simpleIndirectReference.all {
				n.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(n, yyDollar[2].node))
			}

			yyVAL.node = yyDollar[1].simpleIndirectReference.all[0]

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 459:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:5981
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 460:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:5990
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 461:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6003
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 462:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6016
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 463:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6026
		{
			name := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			yyVAL.node = expr.NewVariable(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 464:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6040
		{
			yyVAL.node = expr.NewVariable(yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DollarToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 465:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:6057
		{
			yyVAL.node = nil

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 466:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6063
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 467:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6073
		{
			yyVAL.list = yyDollar[1].list

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 468:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6079
		{
			fetch := expr.NewPropertyFetch(nil, yyDollar[1].node)
			yyVAL.list = []node.Node{fetch}

			// save position
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 469:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6092
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yyVAL.list = append(yyDollar[1].list, fetch)

			// save position
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			// save comments
			addMeta(fetch, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(fetch, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 470:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6106
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yyVAL.list = append(yyDollar[1].list, fetch)

			// save position
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			// save comments
			addMeta(fetch, yyDollar[2].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(fetch, yyDollar[4].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 471:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6120
		{
			fetch := expr.NewPropertyFetch(nil, yyDollar[1].node)
			yyVAL.list = []node.Node{fetch}

			// save position
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 472:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6133
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 473:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6145
		{
			yyVAL.node = yyDollar[2].node

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.OpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 474:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6161
		{
			n := expr.NewVariable(nil)
			yyVAL.simpleIndirectReference = simpleIndirectReference{[]*expr.Variable{n}, n}

			// save position
			n.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(n, yyDollar[1].token.Meta, meta.DollarToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 475:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6174
		{
			n := expr.NewVariable(nil)

			yyDollar[1].simpleIndirectReference.last.SetVarName(n)
			yyDollar[1].simpleIndirectReference.all = append(yyDollar[1].simpleIndirectReference.all, n)
			yyDollar[1].simpleIndirectReference.last = n
			yyVAL.simpleIndirectReference = yyDollar[1].simpleIndirectReference

			// save position
			n.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))

			// save comments
			addMeta(n, yyDollar[2].token.Meta, meta.DollarToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 476:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6194
		{
			if len(yyDollar[1].list) == 0 {
				yyDollar[1].list = []node.Node{expr.NewArrayItem(nil, nil)}
			}

			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 477:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6207
		{
			if yyDollar[1].node.(*expr.ArrayItem).Key == nil && yyDollar[1].node.(*expr.ArrayItem).Val == nil {
				yyVAL.list = []node.Node{}
			} else {
				yyVAL.list = []node.Node{yyDollar[1].node}
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 478:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6221
		{
			yyVAL.node = expr.NewArrayItem(nil, yyDollar[1].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 479:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6230
		{
			item := expr.NewList(yyDollar[3].list)
			yyVAL.node = expr.NewArrayItem(nil, item)

			// save position
			item.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(item))

			// save comments
			addMeta(item, yyDollar[1].token.Meta, meta.ListToken)
			addMeta(item, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(item, yyDollar[4].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 480:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:6246
		{
			yyVAL.node = expr.NewArrayItem(nil, nil)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 481:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:6256
		{
			yyVAL.list = []node.Node{}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 482:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6262
		{
			yyVAL.list = yyDollar[1].list

			if yyDollar[2].token != nil {
				yyVAL.list = append(yyDollar[1].list, expr.NewArrayItem(nil, nil))
			}

			// save comments
			if yyDollar[2].token != nil {
				addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 483:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:6280
		{
			arrayItem := expr.NewArrayItem(yyDollar[3].node, yyDollar[5].node)
			yyVAL.list = append(yyDollar[1].list, arrayItem)

			// save position
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[3].node, yyDollar[5].node))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(arrayItem, yyDollar[4].token.Meta, meta.DoubleArrowToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 484:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6294
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[3].node)
			yyVAL.list = append(yyDollar[1].list, arrayItem)

			// save position
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 485:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6307
		{
			arrayItem := expr.NewArrayItem(yyDollar[1].node, yyDollar[3].node)
			yyVAL.list = []node.Node{arrayItem}

			// save position
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))

			// save comments
			addMeta(arrayItem, yyDollar[2].token.Meta, meta.DoubleArrowToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 486:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6320
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[1].node)
			yyVAL.list = []node.Node{arrayItem}

			// save position
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 487:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:6330
		{
			reference := expr.NewReference(yyDollar[6].node)
			arrayItem := expr.NewArrayItem(yyDollar[3].node, reference)
			yyVAL.list = append(yyDollar[1].list, arrayItem)

			// save position
			reference.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[5].token, yyDollar[6].node))
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[3].node, yyDollar[6].node))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(arrayItem, yyDollar[4].token.Meta, meta.DoubleArrowToken)
			addMeta(reference, yyDollar[5].token.Meta, meta.AmpersandToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 488:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6347
		{
			reference := expr.NewReference(yyDollar[4].node)
			arrayItem := expr.NewArrayItem(nil, reference)
			yyVAL.list = append(yyDollar[1].list, arrayItem)

			// save position
			reference.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[4].node))
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[4].node))

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.CommaToken)
			addMeta(reference, yyDollar[3].token.Meta, meta.AmpersandToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 489:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6363
		{
			reference := expr.NewReference(yyDollar[4].node)
			arrayItem := expr.NewArrayItem(yyDollar[1].node, reference)
			yyVAL.list = []node.Node{arrayItem}

			// save position
			reference.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[4].node))
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))

			// save comments
			addMeta(arrayItem, yyDollar[2].token.Meta, meta.DoubleArrowToken)
			addMeta(reference, yyDollar[3].token.Meta, meta.AmpersandToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 490:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6379
		{
			reference := expr.NewReference(yyDollar[2].node)
			arrayItem := expr.NewArrayItem(nil, reference)
			yyVAL.list = []node.Node{arrayItem}

			// save position
			reference.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			arrayItem.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(reference, yyDollar[1].token.Meta, meta.AmpersandToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 491:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6397
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 492:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6403
		{
			encapsed := scalar.NewEncapsedStringPart(yyDollar[2].token.Value)
			yyVAL.list = append(yyDollar[1].list, encapsed)

			// save position
			encapsed.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))

			// save comments
			addMeta(encapsed, yyDollar[2].token.Meta, meta.EncapsedAndWhitespaceToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 493:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6416
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 494:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6422
		{
			encapsed := scalar.NewEncapsedStringPart(yyDollar[1].token.Value)
			yyVAL.list = []node.Node{encapsed, yyDollar[2].node}

			// save position
			encapsed.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(encapsed, yyDollar[1].token.Meta, meta.EncapsedAndWhitespaceToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 495:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6438
		{
			name := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			yyVAL.node = expr.NewVariable(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 496:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6452
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			yyVAL.node = expr.NewArrayDimFetch(variable, yyDollar[3].node)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(variable, yyDollar[1].token.Meta, meta.VariableToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseSquareBracket)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 497:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6470
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			variable := expr.NewVariable(identifier)
			fetch := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = expr.NewPropertyFetch(variable, fetch)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			fetch.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(variable, yyDollar[1].token.Meta, meta.VariableToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.ObjectOperatorToken)
			addMeta(fetch, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 498:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6490
		{
			yyVAL.node = expr.NewVariable(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DollarOpenCurlyBracesToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 499:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6503
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			yyVAL.node = expr.NewVariable(name)

			// save position
			name.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DollarOpenCurlyBracesToken)
			addMeta(name, yyDollar[2].token.Meta, meta.IdentifierToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 500:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:6519
		{
			identifier := node.NewIdentifier(yyDollar[2].token.Value)
			variable := expr.NewVariable(identifier)
			yyVAL.node = expr.NewArrayDimFetch(variable, yyDollar[4].node)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			variable.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[6].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.DollarOpenCurlyBracesToken)
			addMeta(variable, yyDollar[2].token.Meta, meta.StringVarnameToken)
			addMeta(yyVAL.node, yyDollar[3].token.Meta, meta.OpenSquareBracket)
			addMeta(yyVAL.node, yyDollar[5].token.Meta, meta.CloseSquareBracket)
			addMeta(yyVAL.node, yyDollar[6].token.Meta, meta.CloseCurlyBracesToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 501:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6539
		{
			yyVAL.node = yyDollar[2].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 502:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6548
		{
			yyVAL.node = scalar.NewString(yyDollar[1].token.Value)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.StringToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 503:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6560
		{
			// TODO: add option to handle 64 bit integer
			if _, err := strconv.Atoi(yyDollar[1].token.Value); err == nil {
				yyVAL.node = scalar.NewLnumber(yyDollar[1].token.Value)
			} else {
				yyVAL.node = scalar.NewString(yyDollar[1].token.Value)
			}

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.NumStringToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 504:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6577
		{
			identifier := node.NewIdentifier(strings.TrimLeftFunc(yyDollar[1].token.Value, isDollar))
			yyVAL.node = expr.NewVariable(identifier)

			// save position
			identifier.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.VariableToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 505:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6594
		{
			yyVAL.node = expr.NewIsset(yyDollar[3].list)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IssetToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 506:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6608
		{
			yyVAL.node = expr.NewEmpty(yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.EmptyToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 507:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6622
		{
			yyVAL.node = expr.NewEmpty(yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.EmptyToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 508:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6636
		{
			yyVAL.node = expr.NewInclude(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IncludeToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 509:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6648
		{
			yyVAL.node = expr.NewIncludeOnce(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.IncludeOnceToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 510:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:6660
		{
			yyVAL.node = expr.NewEval(yyDollar[3].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.EvalToken)
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.OpenParenthesisToken)
			addMeta(yyVAL.node, yyDollar[4].token.Meta, meta.CloseParenthesisToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 511:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6674
		{
			yyVAL.node = expr.NewRequire(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.RequireToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 512:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:6686
		{
			yyVAL.node = expr.NewRequireOnce(yyDollar[2].node)

			// save position
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))

			// save comments
			addMeta(yyVAL.node, yyDollar[1].token.Meta, meta.RequireOnceToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 513:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6701
		{
			yyVAL.list = []node.Node{yyDollar[1].node}

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 514:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6707
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)

			// save comments
			addMeta(lastNode(yyDollar[1].list), yyDollar[2].token.Meta, meta.NodeEnd)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 515:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6719
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 516:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:6725
		{
			yyVAL.node = yyDollar[1].node

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 517:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6734
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)

			// save position
			target.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)
			addMeta(target, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 518:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6749
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)

			// save position
			target.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)
			addMeta(target, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 519:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6767
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)

			// save position
			target.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)
			addMeta(target, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	case 520:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:6785
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)

			// save position
			target.SetPosition(yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node.SetPosition(yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			// save comments
			addMeta(yyVAL.node, yyDollar[2].token.Meta, meta.PaamayimNekudotayimToken)
			addMeta(target, yyDollar[3].token.Meta, meta.IdentifierToken)

			yylex.(*Parser).returnTokenToPool(yyDollar, &yyVAL)
		}
	}
	goto yystack /* stack new state and value */
}
